@@ -22,8 +22,8 @@ import click
 
 from aws_orbit.commands import deploy as deploy_commands
 from aws_orbit.commands import destroy as destroy_commands
-from aws_orbit.commands.delete import delete_image
-from aws_orbit.commands.image import build_image, build_profile, delete_profile, list_profiles
+from aws_orbit.commands.build import build_image, build_podsetting
+from aws_orbit.commands.delete import delete_image, delete_podsetting
 from aws_orbit.commands.init import init
 from aws_orbit.commands.list import list_env, list_images
 from aws_orbit.utils import print_dir
@@ -100,6 +100,78 @@ def deploy() -> None:
     pass
 
 
+@deploy.command(name="toolkit")
+@click.option(
+    "--filename",
+    "-f",
+    type=str,
+    help="The target Orbit Workbench manifest file (yaml).",
+    required=True,
+)
+@click.option(
+    "--debug/--no-debug",
+    default=False,
+    help="Enable detailed logging.",
+    show_default=True,
+)
+def deploy_toolkit(
+    filename: str,
+    debug: bool,
+) -> None:
+    """Deploy a Orbit Workbench environment based on a manisfest file (yaml)."""
+    if debug:
+        enable_debug(format=DEBUG_LOGGING_FORMAT)
+    filename = filename if filename[0] in (".", "/") else f"./{filename}"
+    _logger.debug("filename: %s", filename)
+    deploy_commands.deploy_toolkit(
+        filename=filename,
+        debug=debug,
+    )
+
+
+@deploy.command(name="credentials")
+@click.option(
+    "--filename",
+    "-f",
+    type=str,
+    help="The target Orbit Workbench manifest file (yaml).",
+)
+@click.option("--username", "-u", type=str, help="Image Registry username", required=True)
+@click.option(
+    "--password",
+    "-p",
+    type=str,
+    help="Image Registry password",
+)
+@click.option("--registry", "-r", type=str, help="Image Registry name/URL", default="docker.io")
+@click.option(
+    "--debug/--no-debug",
+    default=False,
+    help="Enable detailed logging.",
+    show_default=True,
+)
+def deploy_credentials(
+    filename: str,
+    username: str,
+    password: str,
+    registry: str,
+    debug: bool,
+) -> None:
+    """Deploy Image Registry credentials for use in building and pulling images"""
+    if debug:
+        enable_debug(format=DEBUG_LOGGING_FORMAT)
+    _logger.debug("filename: %s", filename)
+    _logger.debug("username: %s", username)
+    _logger.debug("registry: %s", registry)
+    deploy_commands.deploy_credentials(
+        filename=filename,
+        username=username,
+        password=password,
+        registry=registry,
+        debug=debug,
+    )
+
+
 @deploy.command(name="teams")
 @click.option(
     "--filename",
@@ -136,18 +208,6 @@ def deploy_teams(
     help="The target Orbit Workbench manifest file (yaml).",
     required=True,
 )
-@click.option(
-    "--username",
-    "-u",
-    type=str,
-    help="Dockerhub username (Required only for the first deploy).",
-)
-@click.option(
-    "--password",
-    "-p",
-    type=str,
-    help="Dockerhub password (Required only for the first deploy).",
-)
 @click.option(
     "--skip-images/--build-images",
     default=True,
@@ -164,20 +224,15 @@ def deploy_env(
     filename: str,
     skip_images: bool,
     debug: bool,
-    username: Optional[str] = None,
-    password: Optional[str] = None,
 ) -> None:
     """Deploy a Orbit Workbench environment based on a manisfest file (yaml)."""
     if debug:
         enable_debug(format=DEBUG_LOGGING_FORMAT)
     filename = filename if filename[0] in (".", "/") else f"./{filename}"
     _logger.debug("filename: %s", filename)
-    _logger.debug("username: %s", username)
     _logger.debug("skip_images: %s", skip_images)
     deploy_commands.deploy_env(
         filename=filename,
-        username=username,
-        password=password,
         skip_images=skip_images,
         debug=debug,
     )
@@ -196,18 +251,6 @@ def deploy_env(
     type=str,
     help="The Name of the Orbit Foundation deployment",
 )
-@click.option(
-    "--username",
-    "-u",
-    type=str,
-    help="Dockerhub username (Required only for the first deploy).",
-)
-@click.option(
-    "--password",
-    "-p",
-    type=str,
-    help="Dockerhub password (Required only for the first deploy).",
-)
 @click.option(
     "--codeartifact-domain",
     type=str,
@@ -218,6 +261,21 @@ def deploy_env(
     type=str,
     help="CodeArtifact Repository to pull packages from.",
 )
+@click.option(
+    "--ssl-cert-arn",
+    type=str,
+    help="SSL Certificate to integrate the ALB with.",
+)
+@click.option(
+    "--custom-domain-name",
+    type=str,
+    help="The Custom Domain Name to associate the orbit framework with",
+)
+@click.option(
+    "--role-prefix",
+    type=str,
+    help="The Prefix to attach to the IAM Role",
+)
 @click.option(
     "--internet-accessibility/--no-internet-accessibility",
     default=True,
@@ -225,6 +283,14 @@ def deploy_env(
     "or Isolated (no internet accessibility) subnets.",
     show_default=True,
 )
+@click.option(
+    "--max-availability-zones",
+    default=2,
+    help="The maximum number of Availability Zones to attempt to deploy in the VPC",
+    show_default=True,
+    type=int,
+    required=False,
+)
 @click.option(
     "--debug/--no-debug",
     default=False,
@@ -236,10 +302,12 @@ def deploy_foundation(
     name: Optional[str] = None,
     debug: bool = False,
     internet_accessibility: bool = True,
-    username: Optional[str] = None,
-    password: Optional[str] = None,
     codeartifact_domain: Optional[str] = None,
     codeartifact_repository: Optional[str] = None,
+    ssl_cert_arn: Optional[str] = None,
+    custom_domain_name: Optional[str] = None,
+    max_availability_zones: Optional[int] = None,
+    role_prefix: Optional[str] = None,
 ) -> None:
     """Deploy a Orbit Workbench foundation based on a manisfest file (yaml)."""
     if debug:
@@ -254,16 +322,21 @@ def deploy_foundation(
     _logger.debug("name: %s", name)
     _logger.debug("codeartifact_domain: %s", codeartifact_domain)
     _logger.debug("codeartifact_repository: %s", codeartifact_repository)
-    _logger.debug("username: %s", username)
+    _logger.debug("ssl_cert_arn: %s", ssl_cert_arn)
+    _logger.debug("custom_domain_name: %s", custom_domain_name)
+    _logger.debug("max_availability_zones: %s", max_availability_zones)
+    _logger.debug("role_prefix: %s", role_prefix)
     deploy_commands.deploy_foundation(
         filename=filename,
         name=name,
         codeartifact_domain=codeartifact_domain,
         codeartifact_repository=codeartifact_repository,
-        username=username,
-        password=password,
+        ssl_cert_arn=ssl_cert_arn,
+        custom_domain_name=custom_domain_name,
         debug=debug,
         internet_accessibility=internet_accessibility,
+        max_availability_zones=max_availability_zones,
+        role_prefix=role_prefix,
     )
 
 
@@ -291,18 +364,24 @@ def destroy_teams(env: str, debug: bool) -> None:
 
 @destroy.command(name="env")
 @click.option("--env", "-e", type=str, required=True, help="Destroy Orbit Environment.")
+@click.option(
+    "--preserve-credentials/--destroy-credentials",
+    default=True,
+    help="Preserve any docker credentials in Secrets Manager.",
+    show_default=True,
+)
 @click.option(
     "--debug/--no-debug",
     default=False,
     help="Enable detailed logging.",
     show_default=True,
 )
-def destroy_env(env: str, debug: bool) -> None:
+def destroy_env(env: str, preserve_credentials: bool, debug: bool) -> None:
     """Destroy a Orbit Workbench environment based on a manisfest file (yaml)."""
     if debug:
         enable_debug(format=DEBUG_LOGGING_FORMAT)
     _logger.debug("env: %s", env)
-    destroy_commands.destroy_env(env=env, debug=debug)
+    destroy_commands.destroy_env(env=env, preserve_credentials=preserve_credentials, debug=debug)
 
 
 @destroy.command(name="foundation")
@@ -321,9 +400,27 @@ def destroy_foundation(name: str, debug: bool) -> None:
     destroy_commands.destroy_foundation(env=name, debug=debug)
 
 
+@destroy.command(name="credentials")
+@click.option("--env", "-e", type=str, required=True, help="Destroy Registry Credentials.")
+@click.option("--registry", "-r", type=str, required=True, help="Image Registry.")
+@click.option(
+    "--debug/--no-debug",
+    default=False,
+    help="Enable detailed logging.",
+    show_default=True,
+)
+def destroy_credentials(env: str, registry: str, debug: bool) -> None:
+    """Destroy Image Registry Credentials previously stored"""
+    if debug:
+        enable_debug(format=DEBUG_LOGGING_FORMAT)
+    _logger.debug("env: %s", env)
+    _logger.debug("registry: %s", registry)
+    destroy_commands.destroy_credentials(env=env, registry=registry, debug=debug)
+
+
 @click.group(name="build")
 def build() -> None:
-    """Build images,profiles,etc in your Orbit Workbench."""
+    """Build images,podsettings,etc in your Orbit Workbench."""
     pass
 
 
@@ -466,9 +563,9 @@ def replicate_image_cli(
 
 
 @build.command(name="profile")
-@click.option("--env", "-e", type=str, required=True, help="Orbit Environment.")
-@click.option("--team", "-t", type=str, help="Orbit Team.", required=True)
-@click.argument("profile", type=click.File("r"))
+@click.option("--env", "-e", type=str, required=False, help="Orbit Environment.")
+@click.option("--team", "-t", type=str, help="Orbit Team.", required=False)
+@click.argument("profile", type=click.File("r"), required=False)
 @click.option(
     "--debug/--no-debug",
     default=False,
@@ -476,27 +573,44 @@ def replicate_image_cli(
     show_default=True,
 )
 def add_profile_cli(env: str, team: str, debug: bool, profile: TextIO) -> None:
-    """Build and Deploy a new Docker image into ECR."""
+    raise click.ClickException("Profiles are no longer supported...please use podsettings")
+
+
+@build.command(name="podsetting")
+@click.option("--env", "-e", type=str, required=True, help="Orbit Environment.")
+@click.option("--team", "-t", type=str, required=True, help="Orbit Team.")
+@click.argument("podsetting", type=click.File("r"))
+@click.option(
+    "--debug/--no-debug",
+    default=False,
+    help="Enable detailed logging.",
+    show_default=True,
+)
+def add_podsetting_cli(env: str, team: str, debug: bool, podsetting: TextIO) -> None:
+    """Deploy a new podsetting to the K8s cluster."""
     if debug:
         enable_debug(format=DEBUG_LOGGING_FORMAT)
     _logger.debug("env: %s", env)
     _logger.debug("team: %s", team)
-    profile_str = profile.read()
-    _logger.debug("profile: %s", profile_str)
+    podsetting_str = podsetting.read()
+    _logger.debug("podsetting: %s", podsetting_str)
     _logger.debug("debug: %s", debug)
-    build_profile(env=env, team=team, profile=profile_str, debug=debug)
+    try:
+        build_podsetting(env_name=env, team_name=team, podsetting=podsetting_str, debug=debug)
+    except ImportError:
+        raise click.ClickException('The "utils" submodule is required to use "run" commands')
 
 
 @click.group(name="delete")
 def delete() -> None:
-    """Delete images,profiles,etc in your Orbit Workbench."""
+    """Delete images,podsettings,etc in your Orbit Workbench."""
     pass
 
 
 @delete.command(name="profile")
-@click.option("--env", "-e", type=str, required=True, help="Orbit Environment.")
-@click.option("--team", "-t", type=str, help="Orbit Team.", required=True)
-@click.option("--profile", "-p", type=str, help="Profile name to delete", required=True)
+@click.option("--env", "-e", type=str, required=False, help="Orbit Environment.")
+@click.option("--team", "-t", type=str, help="Orbit Team.", required=False)
+@click.option("--profile", "-p", type=str, help="Profile name to delete", required=False)
 @click.option(
     "--debug/--no-debug",
     default=False,
@@ -504,14 +618,26 @@ def delete() -> None:
     show_default=True,
 )
 def delete_profile_cli(env: str, team: str, profile: str, debug: bool) -> None:
-    """Build and Deploy a new Docker image into ECR."""
+    raise click.ClickException("Profiles are no longer supported...please use podsettings")
+
+
+@delete.command(name="podsetting")
+@click.option("--team", "-t", type=str, help="Orbit Team.", required=True)
+@click.option("--podsetting", "-n", type=str, help="Podsetting name to delete", required=True)
+@click.option(
+    "--debug/--no-debug",
+    default=False,
+    help="Enable detailed logging.",
+    show_default=True,
+)
+def delete_podsetting_cli(team: str, podsetting: str, debug: bool) -> None:
+    """Delete a podsetting"""
     if debug:
         enable_debug(format=DEBUG_LOGGING_FORMAT)
-    _logger.debug("env: %s", env)
     _logger.debug("team: %s", team)
-    _logger.debug("profile: %s", profile)
+    _logger.debug("podsetting: %s", podsetting)
     _logger.debug("debug: %s", debug)
-    delete_profile(env=env, team=team, profile_name=profile, debug=debug)
+    delete_podsetting(namespace=team, podsetting_name=podsetting, debug=debug)
 
 
 @delete.command(name="image")
@@ -535,13 +661,13 @@ def delete_image_cli(env: str, name: str, debug: bool) -> None:
 
 @click.group(name="list")
 def list() -> None:
-    """List images,profiles,etc in your Orbit Workbench."""
+    """List images, etc in your Orbit Workbench."""
     pass
 
 
 @list.command(name="profile")
-@click.option("--env", "-e", type=str, required=True, help="Orbit Environment.")
-@click.option("--team", "-t", type=str, help="Orbit Team.", required=True)
+@click.option("--env", "-e", type=str, required=False, help="Orbit Environment.")
+@click.option("--team", "-t", type=str, help="Orbit Team.", required=False)
 @click.option(
     "--debug/--no-debug",
     default=False,
@@ -549,13 +675,7 @@ def list() -> None:
     show_default=True,
 )
 def list_profiles_cli(env: str, team: str, debug: bool) -> None:
-    """Build and Deploy a new Docker image into ECR."""
-    if debug:
-        enable_debug(format=DEBUG_LOGGING_FORMAT)
-    _logger.debug("env: %s", env)
-    _logger.debug("team: %s", team)
-    _logger.debug("debug: %s", debug)
-    list_profiles(env=env, team=team, debug=debug)
+    raise click.ClickException("Profiles are no longer supported.")
 
 
 @list.command(name="image")
