@@ -12,49 +12,34 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
+import json
 import logging
 import os
 import random
 import string
 from typing import List, Optional, Tuple, cast
 
-import click
-
-from aws_orbit import bundle, dockerhub, remote, toolkit
+from aws_orbit import bundle, remote, toolkit
 from aws_orbit.messages import MessagesContext, stylize
 from aws_orbit.models.changeset import Changeset, dump_changeset_to_str, extract_changeset
 from aws_orbit.models.context import Context, ContextSerDe, FoundationContext
 from aws_orbit.models.manifest import (
     DataNetworkingManifest,
     FoundationManifest,
-    ImageManifest,
+    FrontendNetworkingManifest,
     ImagesManifest,
     Manifest,
     ManifestSerDe,
     NetworkingManifest,
+    manifest_validations,
 )
 from aws_orbit.services import cfn, codebuild
 from aws_orbit.services import cognito as orbit_cognito
-from aws_orbit.services import ssm
+from aws_orbit.services import kms, ssm
 
 _logger: logging.Logger = logging.getLogger(__name__)
 
 
-def _request_dockerhub_credential(msg_ctx: MessagesContext) -> Tuple[str, str]:
-    if msg_ctx.pbar is not None:
-        msg_ctx.pbar.clear()
-    msg_ctx.info("When Container Images are from Dockerhub, " "a Dockerhub login is required.")
-    username = cast(
-        str,
-        click.prompt("Please enter the DockerHub username", type=str, hide_input=False),
-    )
-    password = cast(
-        str,
-        click.prompt("Please enter the DockerHub password", type=str, hide_input=True),
-    )
-    return username, password
-
-
 def _get_images_dirs(context: "Context", manifest_filename: str, skip_images: bool) -> List[Tuple[str, str]]:
     if skip_images:
         dirs: List[Tuple[str, str]] = []
@@ -78,40 +63,13 @@ def _get_config_dirs(context: "Context", manifest_filename: str) -> List[Tuple[s
     return dirs
 
 
-def deploy_toolkit(
+def _deploy_toolkit(
     context: "Context",
-    username: Optional[str],
-    password: Optional[str],
-    msg_ctx: MessagesContext,
     top_level: str = "orbit",
 ) -> None:
-    credential_received: bool = username is not None and password is not None
     stack_exist: bool = cfn.does_stack_exist(stack_name=context.toolkit.stack_name)
-    credential_exist: bool = dockerhub.does_credential_exist(context=context) if stack_exist else False
-    image_manifests = [cast(ImageManifest, getattr(context.images, i)) for i in context.images.names]
-    credential_required: bool = any(
-        [im.get_source(account_id=context.account_id, region=context.region) == "dockerhub" for im in image_manifests]
-    )
-
-    if stack_exist:
-        if credential_required and not credential_exist and not credential_received:
-            username, password = _request_dockerhub_credential(msg_ctx=msg_ctx)
-            dockerhub.store_credential(context=context, username=username, password=password)
-            credential_exist = True
-        elif credential_received:
-            dockerhub.store_credential(
-                context=context,
-                username=cast(str, username),
-                password=cast(str, password),
-            )
-            credential_exist = True
-    else:
+    if not stack_exist:
         context.toolkit.deploy_id = "".join(random.choice(string.ascii_lowercase) for i in range(6))
-        if credential_required and not credential_received:
-            username, password = _request_dockerhub_credential(msg_ctx=msg_ctx)
-            credential_exist = False
-
-    msg_ctx.progress(6)
     _logger.debug("context.toolkit.deploy_id: %s", context.toolkit.deploy_id)
     template_filename: str = toolkit.synth(context=context, top_level=top_level)
     cfn.deploy_template(
@@ -120,12 +78,81 @@ def deploy_toolkit(
     ContextSerDe.fetch_toolkit_data(context=context)
     ContextSerDe.dump_context_to_ssm(context=context)
 
-    if credential_exist is False:
-        dockerhub.store_credential(
+
+def deploy_toolkit(
+    filename: str,
+    debug: bool,
+) -> None:
+    with MessagesContext("Deploying", debug=debug) as msg_ctx:
+        msg_ctx.progress(10)
+
+        manifest: "Manifest" = ManifestSerDe.load_manifest_from_file(filename=filename, type=Manifest)
+        msg_ctx.info(f"Manifest loaded: {filename}")
+        msg_ctx.progress(25)
+
+        context: "Context" = ContextSerDe.load_context_from_manifest(manifest=manifest)
+
+        msg_ctx.info("Current Context loaded")
+        msg_ctx.progress(45)
+
+        _deploy_toolkit(
             context=context,
-            username=cast(str, username),
-            password=cast(str, password),
         )
+        msg_ctx.info("Toolkit deployed")
+        msg_ctx.progress(100)
+
+
+def deploy_credentials(filename: str, username: str, password: str, registry: str, debug: bool) -> None:
+    with MessagesContext("Deploying", debug=debug) as msg_ctx:
+        msg_ctx.progress(2)
+
+        manifest: "Manifest" = ManifestSerDe.load_manifest_from_file(filename=filename, type=Manifest)
+        msg_ctx.info(f"Manifest loaded: {filename}")
+        msg_ctx.progress(3)
+
+        context_parameter_name: str = f"/orbit/{manifest.name}/context"
+        if not ssm.does_parameter_exist(name=context_parameter_name):
+            msg_ctx.error(f"Orbit Environment {manifest.name} cannot be found in the current account and region.")
+            return
+
+        context: "Context" = ContextSerDe.load_context_from_manifest(manifest=manifest)
+        msg_ctx.info("Current Context loaded")
+        msg_ctx.progress(4)
+
+        bundle_path = bundle.generate_bundle(
+            command_name="deploy",
+            context=context,
+        )
+        msg_ctx.progress(11)
+
+        msg_ctx.info("Encrypting credentials with Toolkit KMS Key")
+        ciphertext = kms.encrypt(
+            context=context, plaintext=json.dumps({registry: {"username": username, "password": password}})
+        )
+        msg_ctx.progress(20)
+
+        msg_ctx.info("Starting Remote CodeBuild to deploy credentials")
+        buildspec = codebuild.generate_spec(
+            context=context,
+            plugins=True,
+            cmds_build=[f"orbit remote --command deploy_credentials {context.name} '{ciphertext}'"],
+        )
+        remote.run(
+            command_name="deploy",
+            context=context,
+            bundle_path=bundle_path,
+            buildspec=buildspec,
+            codebuild_log_callback=msg_ctx.progress_bar_callback,
+            timeout=10,
+            overrides={"environmentVariablesOverride": [{"name": "CREDENTIALS_CIPHERTEXT", "value": ciphertext}]},
+        )
+        msg_ctx.info("Registry Credentials deployed")
+        msg_ctx.progress(98)
+
+        if cfn.does_stack_exist(stack_name=context.env_stack_name):
+            context = ContextSerDe.load_context_from_ssm(env_name=manifest.name, type=Context)
+            msg_ctx.info(f"Context updated: {filename}")
+        msg_ctx.progress(100)
 
 
 def deploy_foundation(
@@ -135,8 +162,10 @@ def deploy_foundation(
     internet_accessibility: bool = True,
     codeartifact_domain: Optional[str] = None,
     codeartifact_repository: Optional[str] = None,
-    username: Optional[str] = None,
-    password: Optional[str] = None,
+    ssl_cert_arn: Optional[str] = None,
+    custom_domain_name: Optional[str] = None,
+    max_availability_zones: Optional[int] = None,
+    role_prefix: Optional[str] = None,
 ) -> None:
     with MessagesContext("Deploying", debug=debug) as msg_ctx:
         msg_ctx.progress(2)
@@ -151,12 +180,26 @@ def deploy_foundation(
                     'and "codeartifact-repository" ignored.'
                 )
         elif name:
+            if ssl_cert_arn:
+                if not custom_domain_name:
+                    raise ValueError('If "ssl_cert_arn" is provided, "custom_domain_name" should be provided')
+            if custom_domain_name:
+                if not ssl_cert_arn:
+                    raise ValueError('If "custom_domain_name" is provided, "ssl_cert_arn" should be provided')
+
             manifest: FoundationManifest = FoundationManifest(  # type: ignore
                 name=name,
                 codeartifact_domain=codeartifact_domain,
                 codeartifact_repository=codeartifact_repository,
-                ssm_parameter_name=f"/orbit-foundation/{name}/manifest",
-                networking=NetworkingManifest(data=DataNetworkingManifest(internet_accessible=internet_accessibility)),
+                ssm_parameter_name=f"/orbit-f/{name}/manifest",
+                role_prefix=role_prefix,
+                networking=NetworkingManifest(
+                    max_availability_zones=max_availability_zones,
+                    frontend=FrontendNetworkingManifest(
+                        ssl_cert_arn=ssl_cert_arn, custom_domain_name=custom_domain_name
+                    ),
+                    data=DataNetworkingManifest(internet_accessible=internet_accessibility),
+                ),
             )
         else:
             msg_ctx.error('One of "filename" or "name" is required')
@@ -170,12 +213,9 @@ def deploy_foundation(
         msg_ctx.info("Current Context loaded")
         msg_ctx.progress(4)
 
-        deploy_toolkit(
+        _deploy_toolkit(
             context=cast(Context, context),
-            username=username,
-            password=password,
-            msg_ctx=msg_ctx,
-            top_level="orbit-foundation",
+            top_level="orbit-f",
         )
         msg_ctx.info("Toolkit deployed")
         msg_ctx.progress(8)
@@ -204,8 +244,6 @@ def deploy_env(
     filename: str,
     skip_images: bool,
     debug: bool,
-    username: Optional[str] = None,
-    password: Optional[str] = None,
 ) -> None:
     with MessagesContext("Deploying", debug=debug) as msg_ctx:
         msg_ctx.progress(2)
@@ -214,6 +252,8 @@ def deploy_env(
         msg_ctx.info(f"Manifest loaded: {filename}")
         msg_ctx.progress(3)
 
+        manifest_validations(manifest)
+
         context: "Context" = ContextSerDe.load_context_from_manifest(manifest=manifest)
         image_manifests = {"code_build": manifest.images.code_build}
 
@@ -232,11 +272,8 @@ def deploy_env(
         _logger.debug(f"Changeset:\n{dump_changeset_to_str(changeset=changeset)}")
         msg_ctx.progress(5)
 
-        deploy_toolkit(
+        _deploy_toolkit(
             context=context,
-            username=username,
-            password=password,
-            msg_ctx=msg_ctx,
         )
         msg_ctx.info("Toolkit deployed")
         msg_ctx.progress(10)
