@@ -96,12 +96,14 @@ class NetworkingContext:
     Schema: ClassVar[Type[Schema]] = Schema
     vpc_id: Optional[str] = None
     vpc_cidr_block: Optional[str] = None
+    secondary_cidr: bool = False
     public_subnets: List[SubnetContext] = field(default_factory=list)
     private_subnets: List[SubnetContext] = field(default_factory=list)
     isolated_subnets: List[SubnetContext] = field(default_factory=list)
     availability_zones: Optional[List[str]] = None
     frontend: FrontendNetworkingManifest = FrontendNetworkingManifest()
     data: DataNetworkingManifest = DataNetworkingManifest()
+    max_availability_zones: Optional[int] = None
 
     def _fetch_vpc_cidr(self) -> None:
         ec2 = boto3_resource("ec2")
@@ -140,7 +142,6 @@ class TeamContext:
     jupyterhub_inbound_ranges: List[str]
     image: Optional[str]
     plugins: List[PluginManifest]
-    profiles: List[Dict[str, Union[str, Dict[str, Any]]]]
     efs_life_cycle: Optional[str]
 
     # Context
@@ -169,6 +170,10 @@ class TeamContext:
     team_helm_repository: Optional[str] = None
     user_helm_repository: Optional[str] = None
 
+    # Manifest default
+    authentication_groups: Optional[List[str]] = None
+    profiles: Optional[List[Dict[str, Union[str, Dict[str, Any]]]]] = None
+
     def fetch_team_data(self) -> None:
         _logger.debug("Fetching Team %s data...", self.name)
         values = ssm.get_parameter(name=self.team_ssm_parameter_name)
@@ -186,6 +191,8 @@ class ToolkitManifest:
     stack_name: str
     codebuild_project: str
     deploy_id: Optional[str] = None
+    admin_role: Optional[str] = None
+    admin_role_arn: Optional[str] = None
     kms_arn: Optional[str] = None
     kms_alias: Optional[str] = None
     s3_bucket: Optional[str] = None
@@ -207,11 +214,13 @@ class FoundationContext:
     toolkit: ToolkitManifest
     cdk_toolkit: CdkToolkitManifest
     networking: NetworkingContext = NetworkingContext()
+    is_codeartifact_external: Optional[bool] = None
     user_pool_id: Optional[str] = None
     scratch_bucket_arn: Optional[str] = None
     cognito_users_url: Optional[str] = None
     cognito_external_provider_redirect: Optional[str] = None
     cognito_external_provider_domain: Optional[str] = None
+    role_prefix: Optional[str] = None
     stack_name: Optional[str] = None
     ssm_parameter_name: Optional[str] = None
     resources_ssm_parameter_name: Optional[str] = None
@@ -237,6 +246,7 @@ class Context:
     toolkit: ToolkitManifest
     cdk_toolkit: CdkToolkitManifest
     networking: NetworkingContext
+    role_prefix: Optional[str] = None
     user_pool_id: Optional[str] = None
     scratch_bucket_arn: Optional[str] = None
     cognito_users_url: Optional[str] = None
@@ -346,7 +356,12 @@ def create_teams_context_from_manifest(manifest: "Manifest") -> List[TeamContext
 
 
 def create_networking_context_from_manifest(networking: "NetworkingManifest") -> NetworkingContext:
-    args: Dict[str, Any] = {"frontend": networking.frontend, "data": networking.data}
+    args: Dict[str, Any] = {
+        "frontend": networking.frontend,
+        "data": networking.data,
+        "max_availability_zones": networking.max_availability_zones,
+        "secondary_cidr": networking.secondary_cidr,
+    }
     if networking.vpc_id:
         args["vpc_id"] = networking.vpc_id
         args["public_subnets"] = [
@@ -394,13 +409,10 @@ class ContextSerDe(Generic[T, V]):
             context.policies = manifest.policies
             context.codeartifact_domain = manifest.codeartifact_domain
             context.codeartifact_repository = manifest.codeartifact_repository
+            context.role_prefix = manifest.role_prefix
             context.cognito_external_provider = manifest.cognito_external_provider
             context.cognito_external_provider_label = manifest.cognito_external_provider_label
-            for team_manifest in manifest.teams:
-                team_context: Optional[TeamContext] = context.get_team_by_name(name=team_manifest.name)
-                if team_context:
-                    _logger.debug("Updating context profiles for team %s", team_manifest.name)
-                    team_context.profiles = team_manifest.profiles
+
         else:
             context = Context(
                 name=manifest.name,
@@ -418,6 +430,7 @@ class ContextSerDe(Generic[T, V]):
                 cdk_toolkit=CdkToolkitManifest(stack_name=f"orbit-{manifest.name}-cdk-toolkit"),
                 codeartifact_domain=manifest.codeartifact_domain,
                 codeartifact_repository=manifest.codeartifact_repository,
+                role_prefix=manifest.role_prefix,
                 scratch_bucket_arn=manifest.scratch_bucket_arn,
                 networking=create_networking_context_from_manifest(networking=manifest.networking),
                 images=manifest.images,
@@ -443,7 +456,7 @@ class ContextSerDe(Generic[T, V]):
     @staticmethod
     def _load_foundation_context_from_manifest(manifest: "FoundationManifest") -> FoundationContext:
         _logger.debug("Loading Context from manifest")
-        context_parameter_name: str = f"/orbit-foundation/{manifest.name}/context"
+        context_parameter_name: str = f"/orbit-f/{manifest.name}/context"
         if ssm.does_parameter_exist(name=context_parameter_name):
             context: FoundationContext = ContextSerDe.load_context_from_ssm(
                 env_name=manifest.name, type=FoundationContext
@@ -452,25 +465,28 @@ class ContextSerDe(Generic[T, V]):
             context.policies = manifest.policies
             context.codeartifact_domain = manifest.codeartifact_domain
             context.codeartifact_repository = manifest.codeartifact_repository
+            context.role_prefix = manifest.role_prefix
+            context.networking = create_networking_context_from_manifest(networking=manifest.networking)
         else:
             context = FoundationContext(
                 name=manifest.name,
                 account_id=utils.get_account_id(),
                 region=utils.get_region(),
-                env_tag=f"orbit-foundation-{manifest.name}",
+                env_tag=f"orbit-f-{manifest.name}",
                 ssm_parameter_name=context_parameter_name,
-                resources_ssm_parameter_name=f"/orbit-foundation/{manifest.name}/resources",
+                resources_ssm_parameter_name=f"/orbit-f/{manifest.name}/resources",
                 toolkit=ToolkitManifest(
-                    stack_name=f"orbit-foundation-{manifest.name}-toolkit",
-                    codebuild_project=f"orbit-foundation-{manifest.name}",
+                    stack_name=f"orbit-f-{manifest.name}-toolkit",
+                    codebuild_project=f"orbit-f-{manifest.name}",
                 ),
-                cdk_toolkit=CdkToolkitManifest(stack_name=f"orbit-foundation-{manifest.name}-cdk-toolkit"),
+                cdk_toolkit=CdkToolkitManifest(stack_name=f"orbit-f-{manifest.name}-cdk-toolkit"),
                 codeartifact_domain=manifest.codeartifact_domain,
                 codeartifact_repository=manifest.codeartifact_repository,
+                role_prefix=manifest.role_prefix,
                 networking=create_networking_context_from_manifest(networking=manifest.networking),
                 images=manifest.images,
                 policies=manifest.policies,
-                stack_name=f"orbit-foundation-{manifest.name}",
+                stack_name=f"orbit-f-{manifest.name}",
             )
         ContextSerDe.fetch_toolkit_data(context=context)
         ContextSerDe.dump_context_to_ssm(context=context)
@@ -530,7 +546,7 @@ class ContextSerDe(Generic[T, V]):
             main["Teams"] = [t for t in teams if t]
             return cast(V, Context.Schema().load(data=main, many=False, partial=False, unknown="EXCLUDE"))
         elif type is FoundationContext:
-            context_parameter_name = f"/orbit-foundation/{env_name}/context"
+            context_parameter_name = f"/orbit-f/{env_name}/context"
             main = ssm.get_parameter(name=context_parameter_name)
             return cast(V, FoundationContext.Schema().load(data=main, many=False, partial=False, unknown="EXCLUDE"))
         else:
@@ -542,7 +558,7 @@ class ContextSerDe(Generic[T, V]):
         if not (isinstance(context, Context) or isinstance(context, FoundationContext)):
             raise ValueError("Unknown 'context' Type")
 
-        top_level = "orbit" if isinstance(context, Context) else "orbit-foundation"
+        top_level = "orbit" if isinstance(context, Context) else "orbit-f"
 
         resp_type = Dict[str, List[Dict[str, List[Dict[str, str]]]]]
         try:
@@ -574,6 +590,13 @@ class ContextSerDe(Generic[T, V]):
             if output["ExportName"] == f"{top_level}-{context.name}-kms-arn":
                 _logger.debug("Export value: %s", output["OutputValue"])
                 context.toolkit.kms_arn = output["OutputValue"]
+            if output["ExportName"] == f"{top_level}-{context.name}-admin-role":
+                _logger.debug("Export value: %s", output["OutputValue"])
+                context.toolkit.admin_role = output["OutputValue"]
+            if output["ExportName"] == f"{top_level}-{context.name}-admin-role-arn":
+                _logger.debug("Export value: %s", output["OutputValue"])
+                context.toolkit.admin_role_arn = output["OutputValue"]
+
         if context.toolkit.deploy_id is None:
             raise RuntimeError(
                 f"Stack {context.toolkit.stack_name} does not have the expected {top_level}-{context.name}-deploy-id output."
@@ -582,6 +605,14 @@ class ContextSerDe(Generic[T, V]):
             raise RuntimeError(
                 f"Stack {context.toolkit.stack_name} does not have the expected {top_level}-{context.name}-kms-arn output."
             )
+        if context.toolkit.admin_role is None:
+            raise RuntimeError(
+                f"Stack {context.toolkit.stack_name} does not have the expected {top_level}-{context.name}-admin-role output."
+            )
+        if context.toolkit.admin_role_arn is None:
+            raise RuntimeError(
+                f"Stack {context.toolkit.stack_name} does not have the expected {top_level}-{context.name}-admin-role-arn output."
+            )
         context.toolkit.kms_alias = f"{top_level}-{context.name}-{context.toolkit.deploy_id}"
         context.toolkit.s3_bucket = (
             f"{top_level}-{context.name}-toolkit-{context.account_id}-{context.toolkit.deploy_id}"
