@@ -58,8 +58,8 @@ class TeamManifest:
     jupyterhub_inbound_ranges: List[str] = field(default_factory=lambda: ["0.0.0.0/0"])
     image: Optional[str] = None
     plugins: List[PluginManifest] = field(default_factory=list)
-    profiles: List[Dict[str, Union[str, Dict[str, Any]]]] = field(default_factory=list)
     efs_life_cycle: Optional[str] = None
+    authentication_groups: Optional[List[str]] = None
 
 
 @dataclass(base_schema=BaseSchema, frozen=True)
@@ -97,12 +97,14 @@ class ManagedNodeGroupManifest:
     nodes_num_min: int = 1
     labels: Dict[str, str] = field(default_factory=dict)
     enable_virtual_gpu: bool = False
+    availability_zones: Optional[List[str]] = None
+    efa_enabled: Optional[bool] = None
 
 
 @dataclass(base_schema=BaseSchema, frozen=True)
 class CodeBuildImageManifest(ImageManifest):
     repository: Optional[str] = "public.ecr.aws/v3o4w1g6/aws-orbit-workbench/code-build-base"
-    version: Optional[str] = "1.0.0"
+    version: Optional[str] = "2.0.0"
 
 
 @dataclass(base_schema=BaseSchema, frozen=True)
@@ -164,6 +166,7 @@ class FrontendNetworkingManifest:
     Schema: ClassVar[Type[Schema]] = Schema
     load_balancers_subnets: List[str] = field(default_factory=list)
     ssl_cert_arn: Optional[str] = None
+    custom_domain_name: Optional[str] = None
 
 
 @dataclass(base_schema=BaseSchema, frozen=True)
@@ -177,9 +180,11 @@ class DataNetworkingManifest:
 class NetworkingManifest:
     Schema: ClassVar[Type[Schema]] = Schema
     vpc_id: Optional[str] = None
+    secondary_cidr: bool = False
     public_subnets: List[str] = field(default_factory=list)
     private_subnets: List[str] = field(default_factory=list)
     isolated_subnets: List[str] = field(default_factory=list)
+    max_availability_zones: Optional[int] = None
     frontend: FrontendNetworkingManifest = FrontendNetworkingManifest()
     data: DataNetworkingManifest = DataNetworkingManifest()
 
@@ -188,6 +193,7 @@ class NetworkingManifest:
 class FoundationManifest:
     Schema: ClassVar[Type[Schema]] = Schema
     name: str
+    role_prefix: Optional[str] = None
     codeartifact_domain: Optional[str] = None
     codeartifact_repository: Optional[str] = None
     images: FoundationImagesManifest = FoundationImagesManifest()
@@ -200,6 +206,7 @@ class FoundationManifest:
 class Manifest:
     Schema: ClassVar[Type[Schema]] = Schema
     name: str
+    role_prefix: Optional[str] = None
     user_pool_id: Optional[str] = None
     scratch_bucket_arn: Optional[str] = None
     eks_system_masters_roles: Optional[List[str]] = cast(List[str], field(default_factory=list))
@@ -232,11 +239,11 @@ def _add_ssm_param_injector(tag: str = "!SSM") -> Set[str]:
     to be parsed: ${SSM_PARAMETER_PATH::JSONPATH}.
     E.g.:
     database:
-        host: !SSM ${/orbit-foundation/dev-env/resources::/UserAccessPolicy}
-        port: !SSM ${/orbit-foundation/dev-env/resources::/PublicSubnet/*}
+        host: !SSM ${/orbit-f/dev-env/resources::/UserAccessPolicy}
+        port: !SSM ${/orbit-f/dev-env/resources::/PublicSubnet/*}
     """
     # pattern for global vars: look for ${word}
-    pattern = re.compile(".*?\${(.*)}.*?")  # noqa: W605
+    pattern = re.compile(".*?\${([^}]+::[^}]*)}.*?")  # noqa: W605
     loader = yaml.SafeLoader
 
     # the tag will be used to mark where to start searching for the pattern
@@ -306,7 +313,7 @@ def _add_env_var_injector(tag: str = "!ENV") -> None:
         something_else: !ENV '${AWESOME_ENV_VAR}/var/${A_SECOND_AWESOME_VAR}'
     """
     # pattern for global vars: look for ${word}
-    pattern = re.compile(".*?\${(.*)}.*?")  # noqa: W605
+    pattern = re.compile(".*?\${([^}]+::[^}]*)}.*?")  # noqa: W605
     loader = yaml.SafeLoader
 
     # the tag will be used to mark where to start searching for the pattern
@@ -359,7 +366,7 @@ class ManifestSerDe(Generic[T]):
             raw["SsmParameterName"] = f"/orbit/{raw['Name']}/manifest"
             manifest: T = cast(T, Manifest.Schema().load(data=raw, many=False, partial=False, unknown=EXCLUDE))
         elif type is FoundationManifest:
-            raw["SsmParameterName"] = f"/orbit-foundation/{raw['Name']}/manifest"
+            raw["SsmParameterName"] = f"/orbit-f/{raw['Name']}/manifest"
             manifest = cast(T, FoundationManifest.Schema().load(data=raw, many=False, partial=False, unknown=EXCLUDE))
         else:
             raise ValueError("Unknown 'manifest' Type")
@@ -395,7 +402,7 @@ class ManifestSerDe(Generic[T]):
             manifest_parameter_name = manifest.ssm_parameter_name
         elif isinstance(manifest, FoundationManifest):
             content = cast(Dict[str, Any], FoundationManifest.Schema().dump(manifest))
-            ssm.cleanup_manifest(env_name=manifest.name, top_level="orbit-foundation")
+            ssm.cleanup_manifest(env_name=manifest.name, top_level="orbit-f")
             manifest_parameter_name = manifest.ssm_parameter_name
         else:
             raise ValueError("Unknown 'manifest' Type")
@@ -415,10 +422,35 @@ class ManifestSerDe(Generic[T]):
             main["Teams"] = teams
             return cast(T, Manifest.Schema().load(data=main, many=False, partial=False, unknown=EXCLUDE))
         elif type is FoundationManifest:
-            context_parameter_name = f"/orbit-foundation/{env_name}/manifest"
+            context_parameter_name = f"/orbit-f/{env_name}/manifest"
             main = ssm.get_parameter_if_exists(name=context_parameter_name)
             if main is None:
                 return None
             return cast(T, FoundationManifest.Schema().load(data=main, many=False, partial=False, unknown=EXCLUDE))
         else:
             raise ValueError("Unknown 'manifest' Type")
+
+
+def manifest_validations(manifest: Manifest) -> None:
+    for managed_nodegroup in manifest.managed_nodegroups:
+        _logger.debug(f"Validating managed node group {managed_nodegroup} ")
+        if managed_nodegroup.nodes_num_desired < 1:
+            raise ValueError(f"{managed_nodegroup.name}  number of desired nodes should be greater than 0")
+
+    # Handle IAM role name 64 character limit validation
+    region_len = len(utils.get_region())
+    env_len = len(manifest.name)
+    env_region_len = env_len + region_len
+    _logger.debug(f"env_region_len={env_region_len}")
+    env_region_max = 28
+    env_region_team_max = 51
+    if env_region_len > env_region_max:
+        raise ValueError(f"Orbit accepts max combined length of {env_region_max} characters for env and region")
+
+    max_team_len = max([len(team.name) for team in manifest.teams])
+    env_region_team_len = env_region_len + max_team_len
+    _logger.debug(f"env_region_team_len={env_region_team_len}")
+    if env_region_team_len > env_region_team_max:
+        raise ValueError(
+            f"Orbit accepts max combined length of {env_region_team_max} characters for env, region, and team name"
+        )
