@@ -17,7 +17,7 @@ import logging
 import os
 import shutil
 import sys
-from typing import cast
+from typing import Any, cast
 
 import aws_cdk.aws_cognito as cognito
 import aws_cdk.aws_ec2 as ec2
@@ -25,15 +25,32 @@ import aws_cdk.aws_iam as iam
 import aws_cdk.aws_lambda_python as lambda_python
 import aws_cdk.aws_sam as sam
 import aws_cdk.aws_ssm as ssm
-from aws_cdk import aws_lambda
-from aws_cdk.core import App, Construct, Duration, Environment, IConstruct, Stack, Tags
+import jsii
+from aws_cdk import aws_lambda, core
+from aws_cdk.core import App, Aspects, Construct, Duration, Environment, IAspect, IConstruct, Stack, Tags
+from botocore.exceptions import ClientError
 
 from aws_orbit.models.context import Context, ContextSerDe
 from aws_orbit.remote_files.cdk import _lambda_path
+from aws_orbit.remote_files.cdk.team_builders.codeartifact import DeployCodeArtifact
 from aws_orbit.services import cognito as orbit_cognito
+from aws_orbit.utils import boto3_client
 
 _logger: logging.Logger = logging.getLogger(__name__)
 
+# Client Connections
+CA_CLIENT = boto3_client("codeartifact")
+
+"""
+Custom Implementation of NonPathRole is to extract EKS Roles (NodeGroup and Fargate).
+https://github.com/kubernetes-sigs/aws-iam-authenticator/issues/268
+"""
+
+
+class NonPathRole(iam.Role):
+    def __init__(self, scope: core.Construct, id: str, **kwargs: Any):
+        super().__init__(scope, id, **kwargs)
+
 
 class Env(Stack):
     def __init__(
@@ -56,6 +73,21 @@ class Env(Stack):
             raise ValueError("self.context.networking.vpc_id is None.")
         if self.context.networking.availability_zones is None:
             raise ValueError("self.context.networking.availability_zones is None.")
+
+        # Checks if CodeArtifact exists outside of the scope of Orbit, else creates it.
+        if not self.context.codeartifact_domain and not self.context.codeartifact_repository:
+            if not self._check_ca_domain_existence() and not self._check_ca_repo_existence():
+                _logger.debug("Deploying Codeartifact resources via Orbit Environment")
+                DeployCodeArtifact(self, id="CodeArtifact-from-Env")
+            else:
+                _logger.debug(
+                    "Detected CodeArtifact domain: aws-orbit and CodeArtifact Repo: python-repository in the account"
+                )
+        else:
+            _logger.debug(
+                "Detected CodeArtifact resources from the framework's metadata, and not deploying Codeartifact"
+            )
+
         self.i_vpc = ec2.Vpc.from_vpc_attributes(
             scope=self,
             id="vpc",
@@ -84,8 +116,28 @@ class Env(Stack):
         self.context_parameter = self._create_manifest_parameter()
         self._create_post_authentication_lambda()
 
+    def _check_ca_domain_existence(self) -> bool:
+        try:
+            CA_CLIENT.describe_domain(domain="aws-orbit")
+        except ClientError as ex:
+            if ex.response["Error"]["Code"] == "ResourceNotFoundException":
+                return False
+            else:
+                raise ex
+        return True
+
+    def _check_ca_repo_existence(self) -> bool:
+        try:
+            CA_CLIENT.describe_repository(domain="aws-orbit", repository="python-repository")
+        except ClientError as ex:
+            if ex.response["Error"]["Code"] == "ResourceNotFoundException":
+                return False
+            else:
+                raise ex
+        return True
+
     def _create_role_cluster(self) -> iam.Role:
-        name: str = f"orbit-{self.context.name}-eks-cluster-role"
+        name: str = f"orbit-{self.context.name}-{self.context.region}-eks-cluster-role"
         role = iam.Role(
             scope=self,
             id=name,
@@ -132,6 +184,7 @@ class Env(Stack):
                                 "fsx:CreateFileSystem",
                                 "fsx:DeleteFileSystem",
                                 "fsx:DescribeFileSystems",
+                                "fsx:TagResource",
                             ],
                             resources=["*"],
                         ),
@@ -142,9 +195,9 @@ class Env(Stack):
 
         return role
 
-    def _create_role_fargate_profile(self) -> iam.Role:
-        name: str = f"orbit-{self.context.name}-eks-fargate-profile-role"
-        return iam.Role(
+    def _create_role_fargate_profile(self) -> NonPathRole:
+        name: str = f"orbit-{self.context.name}-{self.context.region}-eks-fargate-profile-role"
+        role = NonPathRole(
             scope=self,
             id=name,
             role_name=name,
@@ -180,10 +233,11 @@ class Env(Stack):
                 )
             },
         )
+        return role
 
-    def _create_env_nodegroup_role(self) -> iam.Role:
-        name: str = f"orbit-{self.context.name}-eks-nodegroup-role"
-        role = iam.Role(
+    def _create_env_nodegroup_role(self) -> NonPathRole:
+        name: str = f"orbit-{self.context.name}-{self.context.region}-eks-nodegroup-role"
+        role = NonPathRole(
             scope=self,
             id=name,
             role_name=name,
@@ -200,7 +254,7 @@ class Env(Stack):
         return role
 
     def _create_cluster_autoscaler_role(self) -> iam.Role:
-        name: str = f"orbit-{self.context.name}-cluster-autoscaler-role"
+        name: str = f"orbit-{self.context.name}-{self.context.region}-cluster-autoscaler-role"
         return iam.Role(
             scope=self,
             id=name,
@@ -264,7 +318,7 @@ class Env(Stack):
                 )
             ],
         )
-        name = f"{self.id}-cognito-authenticated-identity-role"
+        name = f"{self.id}-{self.context.region}-cognito-auth-identity-role"
         authenticated_role = iam.Role(
             scope=self,
             id=name,
@@ -306,7 +360,7 @@ class Env(Stack):
                 ),
             },
         )
-        name = f"{self.id}-cognito-unauthenticated-identity-role"
+        name = f"{self.id}-{self.context.region}-cognito-unauth-identity-role"
         unauthenticated_role = iam.Role(
             scope=self,
             id=name,
@@ -411,8 +465,7 @@ class Env(Stack):
             parameters={"LayerName": k8s_layer_name},
         )
 
-        role_name = f"orbit-{self.context.name}-admin"
-        role_arn = f"arn:aws:iam::{self.context.account_id}:role/{role_name}"
+        role_arn = cast(str, self.context.toolkit.admin_role_arn)
 
         lambda_python.PythonFunction(
             scope=self,
@@ -455,6 +508,9 @@ class Env(Stack):
                 "PATH": "/var/lang/bin:/usr/local/bin:/usr/bin/:/bin:/opt/bin:/opt/awscli:/opt/kubectl:/opt/helm",
                 "ORBIT_ENV": self.context.name,
                 "ACCOUNT_ID": self.context.account_id,
+                "ROLE_PREFIX": f"/{self.context.role_prefix}/" if self.context.role_prefix else "/",
+                "ORBIT_API_VERSION": "v1",
+                "ORBIT_API_GROUP": "orbit.aws",
             },
             layers=[
                 aws_lambda.LayerVersion.from_layer_version_arn(
@@ -514,11 +570,28 @@ def main() -> None:
     shutil.rmtree(outdir)
 
     app = App(outdir=outdir)
-    Env(
+
+    @jsii.implements(core.IAspect)
+    class AddDeployPathIAM:
+        """ Implementing CDK Aspects to add optional IAM Role prefix to IAM roles """
+
+        def visit(self, obj: core.IConstruct) -> None:
+            """ Function to implement a path pattern """
+            if isinstance(obj, NonPathRole):
+                cfn_role = obj.node.find_child("Resource")
+                path = "/"
+                cfn_role.add_property_override("Path", path)
+            elif isinstance(obj, iam.Role):
+                cfn_role = obj.node.find_child("Resource")
+                path = f"/{context.role_prefix}/" if context.role_prefix else "/"
+                cfn_role.add_property_override("Path", path)
+
+    env_stack = Env(
         scope=app,
         id=context.env_stack_name,
         context=context,
     )
+    Aspects.of(scope=cast(IConstruct, env_stack)).add(cast(IAspect, AddDeployPathIAM()))
     app.synth(force=True)
 
 
