@@ -19,6 +19,7 @@ import shutil
 import sys
 from typing import Any, Dict, List, cast
 
+import jsii
 from aws_cdk import aws_cognito as cognito
 from aws_cdk import aws_ec2 as ec2
 from aws_cdk import aws_iam as iam
@@ -26,9 +27,10 @@ from aws_cdk import aws_kms as kms
 from aws_cdk import aws_s3 as s3
 from aws_cdk import aws_ssm as ssm
 from aws_cdk import core
-from aws_cdk.core import App, CfnOutput, Construct, Duration, Stack, Tags
+from aws_cdk.core import App, Aspects, CfnOutput, Construct, Duration, Stack, Tags
 
 from aws_orbit.models.context import ContextSerDe, FoundationContext
+from aws_orbit.remote_files.cdk.team_builders.codeartifact import DeployCodeArtifact
 from aws_orbit.remote_files.cdk.team_builders.efs import EfsBuilder
 from aws_orbit.remote_files.cdk.team_builders.s3 import S3Builder
 
@@ -82,7 +84,7 @@ class FoundationStack(Stack):
         toolkit_s3_bucket_name: str = context.toolkit.s3_bucket
         acct: str = core.Aws.ACCOUNT_ID
         self.bucket_names: Dict[str, Any] = {
-            "scratch-bucket": f"orbit-foundation-{self.env_name}-scratch-{acct}-{context.toolkit.deploy_id}",
+            "scratch-bucket": f"orbit-f-{self.env_name}-scratch-{acct}-{context.toolkit.deploy_id}",
             "toolkit-bucket": toolkit_s3_bucket_name,
         }
         self._build_kms_key_for_env()
@@ -96,7 +98,7 @@ class FoundationStack(Stack):
 
         self.efs_fs = EfsBuilder.build_file_system(
             scope=self,
-            name="orbit-fs",
+            name=self.env_name,
             efs_life_cycle="AFTER_7_DAYS",
             vpc=cast(ec2.IVpc, self.vpc),
             efs_security_group=cast(ec2.ISecurityGroup, self._vpc_security_group),
@@ -106,6 +108,15 @@ class FoundationStack(Stack):
 
         self.user_pool: cognito.UserPool = self._create_user_pool()
 
+        # Checks if CodeArtifact exists outside of the scope of Orbit, else creates it.
+        if self.context.codeartifact_domain and self.context.codeartifact_repository:
+            self.domain_name = self.context.codeartifact_domain
+            self.repository_name = self.context.codeartifact_repository
+        else:
+            self.codeartifact = DeployCodeArtifact(self, id="CodeArtifact-from-Fndn")
+            self.domain_name = self.codeartifact.artifact_domain.domain_name
+            self.repository_name = self.codeartifact.pypi_repo.repository_name
+
         self._ssm_parameter = ssm.StringParameter(
             self,
             id="/orbit/DemoParams",
@@ -127,6 +138,11 @@ class FoundationStack(Stack):
                     "SharedEfsSgId": self._vpc_security_group.security_group_id,
                     "UserPoolProviderName": self.user_pool.user_pool_provider_name,
                     "SslCertArn": self.ssl_cert_arn,
+                    "CodeartifactDomain": self.domain_name,
+                    "CodeartifactRepository": self.repository_name,
+                    "IsCodeartifactExternal": True
+                    if self.context.codeartifact_domain and self.context.codeartifact_repository
+                    else False,
                 }
             ),
             type=ssm.ParameterType.STRING,
@@ -139,33 +155,33 @@ class FoundationStack(Stack):
         CfnOutput(
             scope=self,
             id=f"{id}vpcid",
-            export_name=f"orbit-foundation-{self.env_name}-vpc-id",
+            export_name=f"orbit-f-{self.env_name}-vpc-id",
             value=self.vpc.vpc_id,
         )
 
         CfnOutput(
             scope=self,
             id=f"{id}publicsubnetsids",
-            export_name=f"orbit-foundation-{self.env_name}-public-subnet-ids",
+            export_name=f"orbit-f-{self.env_name}-public-subnet-ids",
             value=",".join(self.public_subnets.subnet_ids),
         )
         CfnOutput(
             scope=self,
             id=f"{id}privatesubnetsids",
-            export_name=f"orbit-foundation-{self.env_name}-private-subnet-ids",
+            export_name=f"orbit-f-{self.env_name}-private-subnet-ids",
             value=",".join(self.private_subnets.subnet_ids),
         )
         if not context.networking.data.internet_accessible:
             CfnOutput(
                 scope=self,
                 id=f"{id}isolatedsubnetsids",
-                export_name=f"orbit-foundation-{self.env_name}-isolated-subnet-ids",
+                export_name=f"orbit-f-{self.env_name}-isolated-subnet-ids",
                 value=",".join(self.isolated_subnets.subnet_ids),
             )
         CfnOutput(
             scope=self,
             id=f"{id}nodesubnetsids",
-            export_name=f"orbit-foundation-{self.env_name}-nodes-subnet-ids",
+            export_name=f"orbit-f-{self.env_name}-nodes-subnet-ids",
             value=",".join(self.nodes_subnets.subnet_ids),
         )
 
@@ -213,7 +229,9 @@ class FoundationStack(Stack):
             cidr="10.0.0.0/16",
             enable_dns_hostnames=True,
             enable_dns_support=True,
-            max_azs=2,
+            max_azs=context.networking.max_availability_zones
+            if context.networking.max_availability_zones is not None
+            else 2,
             nat_gateways=1,
             subnet_configuration=subnet_configuration,
         )
@@ -255,6 +273,7 @@ class FoundationStack(Stack):
             ),
             user_pool_name=f"orbit-{self.env_name}-user-pool",
         )
+        pool.apply_removal_policy(policy=core.RemovalPolicy.DESTROY)
         pool.add_domain(
             id="orbit-user-pool-domain",
             cognito_domain=cognito.CognitoDomainOptions(
@@ -377,8 +396,28 @@ def main() -> None:
     os.makedirs(outdir, exist_ok=True)
     shutil.rmtree(outdir)
 
-    app = App(outdir=outdir)
-    FoundationStack(scope=app, id=cast(str, context.stack_name), context=context, ssl_cert_arn=ssl_cert_arn)
+    app = App(
+        outdir=outdir,
+    )
+
+    @jsii.implements(core.IAspect)
+    class AddDeployPathIAM:
+        """ Implementing CDK Aspects to add optional IAM Role prefix to IAM roles """
+
+        def visit(self, node: core.IConstruct) -> None:
+            """ Function to implement a path pattern """
+            if isinstance(node, iam.CfnRole):
+                node.path = f"/{context.role_prefix}/" if context.role_prefix else "/"
+
+    foundation_stack = FoundationStack(
+        scope=app,
+        id=cast(str, context.stack_name),
+        context=context,
+        ssl_cert_arn=ssl_cert_arn,
+        env=core.Environment(account=os.environ["CDK_DEFAULT_ACCOUNT"], region=os.environ["CDK_DEFAULT_REGION"]),
+    )
+
+    Aspects.of(scope=cast(core.IConstruct, foundation_stack)).add(cast(core.IAspect, AddDeployPathIAM()))
     app.synth(force=True)
 
 
