@@ -6,7 +6,8 @@ import time
 from typing import Any, Dict, List, Optional, cast
 
 import boto3
-from kubernetes import client, config
+from kubernetes import client, config, dynamic
+from kubernetes.client import api_client
 from kubernetes.client.rest import ApiException
 
 logger = logging.getLogger()
@@ -14,10 +15,17 @@ logger.setLevel(logging.INFO)
 
 ORBIT_ENV = os.environ.get("ORBIT_ENV")
 ACCOUNT_ID = os.environ.get("ACCOUNT_ID")
+REGION = os.environ.get("REGION")
+ROLE_PREFIX = os.environ.get("ROLE_PREFIX")
+ORBIT_API_VERSION = os.environ.get("ORBIT_API_VERSION", "v1")
+ORBIT_API_GROUP = os.environ.get("ORBIT_API_GROUP", "orbit.aws")
+ORBIT_SYSTEM_NAMESPACE = os.environ.get("ORBIT_SYSTEM_NAMESPACE", "orbit-system")
+ORBIT_STATE_PATH = os.environ.get("ORBIT_STATE_PATH", "/state")
+USERSPACE_CR_KIND = "UserSpace"
 KUBECONFIG_PATH = "/tmp/.kubeconfig"
 
-ssm = boto3.client("ssm")
 
+ssm = boto3.client("ssm")
 context = ssm.get_parameter(Name=f"/orbit/{ORBIT_ENV}/context")
 EFS_FS_ID = json.loads(context.get("Parameter").get("Value")).get("SharedEfsFsId")
 
@@ -26,12 +34,15 @@ def handler(event: Dict[str, Any], context: Optional[Dict[str, Any]]) -> Any:
     create_kubeconfig()
 
     api_CoreV1 = client.CoreV1Api()
+    userspace_dc = dynamic.DynamicClient(client=api_client.ApiClient()).resources.get(
+        group=ORBIT_API_GROUP, api_version=ORBIT_API_VERSION, kind=USERSPACE_CR_KIND
+    )
 
-    manage_user_namespace(event, api_CoreV1)
+    manage_user_namespace(event, api_CoreV1, userspace_dc)
 
 
 def run_command(cmd: str) -> None:
-    """ Module to run shell commands. """
+    """Module to run shell commands."""
     cmds = cmd.split(" ")
     try:
         output = subprocess.run(cmds, stderr=subprocess.STDOUT, shell=False, timeout=120, universal_newlines=True)
@@ -47,7 +58,7 @@ def create_kubeconfig() -> None:
         (
             "aws eks update-kubeconfig "
             f"--name orbit-{ORBIT_ENV} "
-            f"--role-arn arn:aws:iam::{ACCOUNT_ID}:role/orbit-{ORBIT_ENV}-admin "
+            f"--role-arn arn:aws:iam::{ACCOUNT_ID}:role{ROLE_PREFIX}orbit-{ORBIT_ENV}-{REGION}-admin "
             f"--kubeconfig {KUBECONFIG_PATH}"
         )
     )
@@ -60,30 +71,49 @@ def create_kubeconfig() -> None:
         raise Exception("Could not configure kubernetes python client")
 
 
-def create_user_efs_endpoint(user: str, team_name: str) -> Dict[str, Any]:
-    efs = boto3.client("efs")
-
-    return cast(
-        Dict[str, str],
-        efs.create_access_point(
-            FileSystemId=EFS_FS_ID,
-            PosixUser={"Uid": 1000, "Gid": 100},
-            RootDirectory={
-                "Path": f"/{team_name}/private/{user}",
-                "CreationInfo": {"OwnerUid": 1000, "OwnerGid": 100, "Permissions": "770"},
-            },
-            Tags=[{"Key": "TeamSpace", "Value": team_name}, {"Key": "Env", "Value": os.environ.get("ORBIT_ENV")}],
-        ),
-    )
+def create_userspace(
+    userspace_dc: dynamic.DynamicClient,
+    name: str,
+    env: str,
+    space: str,
+    team: str,
+    user: str,
+    team_efsid: str,
+    user_email: str,
+    owner_reference: Optional[Dict[str, str]] = None,
+    labels: Optional[Dict[str, str]] = None,
+    annnotations: Optional[Dict[str, str]] = None,
+) -> None:
+    userspace: Dict[str, Any] = {
+        "apiVersion": f"{ORBIT_API_GROUP}/{ORBIT_API_VERSION}",
+        "kind": USERSPACE_CR_KIND,
+        "metadata": {"name": name, "labels": labels, "annotations": annnotations, "namespace": name},
+        "spec": {
+            "env": env,
+            "space": space,
+            "team": team,
+            "user": user,
+            "teamEfsId": team_efsid,
+            "userEmail": user_email,
+        },
+    }
+    if owner_reference is not None:
+        userspace["metadata"]["ownerReferences"] = [owner_reference]
+    logger.info(f"userspace={userspace}")
+    userspace_dc.create(namespace=name, body=userspace)
 
 
 def create_user_namespace(
     api: client.CoreV1Api,
+    userspace_dc: dynamic.DynamicClient,
     user_name: str,
     user_email: str,
     expected_user_namespaces: Dict[str, str],
     namespaces: List[str],
 ) -> None:
+    env = os.environ.get("ORBIT_ENV", "")
+    if not env:
+        raise ValueError("Orbit Environment ORBIT_ENV is required")
     for team, user_ns in expected_user_namespaces.items():
         try:
             team_namespace = api.read_namespace(name=team).to_dict()
@@ -93,16 +123,11 @@ def create_user_namespace(
             logger.exception("Error retrieving Team Namespace")
             team_uid = None
         if user_ns not in namespaces:
-            logger.info(f"Creating EFS endpoint for {user_ns}...")
-            resp = create_user_efs_endpoint(user=user_name, team_name=team)
-            access_point_id = resp.get("AccessPointId")
-
             logger.info(f"User namespace {user_ns} doesnt exist. Creating...")
             kwargs = {
                 "name": user_ns,
                 "annotations": {"owner": user_email},
                 "labels": {
-                    "orbit/efs-access-point-id": access_point_id,
                     "orbit/efs-id": EFS_FS_ID,
                     "orbit/env": os.environ.get("ORBIT_ENV"),
                     "orbit/space": "user",
@@ -120,61 +145,65 @@ def create_user_namespace(
             body.metadata = client.V1ObjectMeta(**kwargs)
 
             try:
+                # create userspace namespace resource
                 api.create_namespace(body=body)
                 logger.info(f"Created namespace {user_ns}")
-            except ApiException:
-                logger.error(f"Exception when trying to create user namespace {user_ns}")
+            except ApiException as ae:
+                logger.warning(f"Exception when trying to create user namespace {user_ns}")
+                logger.warning(ae.body)
 
-
-def delete_user_efs_endpoint(user_name: str, user_namespace: str, api: client.CoreV1Api) -> None:
-    efs = boto3.client("efs")
-
-    logger.info(f"Fetching the EFS access point in the namespace {user_namespace} for user {user_name}")
-
-    try:
-        user_namespace_info = api.read_namespace(name=user_namespace).to_dict()
-        efs_access_point_id = user_namespace_info.get("metadata").get("labels").get("orbit/efs-access-point-id")
-    except ApiException:
-        logger.info(f"Exception when trying to read namespace {user_namespace}")
-
-    logger.info(f"Deleting the EFS access point {efs_access_point_id} for user {user_name}")
-
-    try:
-        efs.delete_access_point(AccessPointId=efs_access_point_id)
-        logger.info(f"Access point {efs_access_point_id} deleted")
-    except efs.exceptions.AccessPointNotFound:
-        logger.error(f"Access point not found: {efs_access_point_id}")
-    except efs.exceptions.InternalServerError as e:
-        logger.error(e)
+            try:
+                # create userspace custom resource for the given user namespace
+                logger.info(f"Creating userspace custom resource {user_ns}")
+                create_userspace(
+                    userspace_dc=userspace_dc,
+                    name=user_ns,
+                    env=env,
+                    space="user",
+                    team=team,
+                    user=user_name,
+                    team_efsid=EFS_FS_ID,
+                    user_email=user_email,
+                )
+                logger.info(f"Created userspace custom resource {user_ns}")
+            except ApiException as ae:
+                logger.warning(f"Exception when trying to create userspace custom resource {user_ns}")
+                logger.warning(ae.body)
 
 
 def delete_user_namespace(
-    api: client.CoreV1Api, user_name: str, expected_user_namespaces: Dict[str, str], namespaces: List[str]
+    api: client.CoreV1Api,
+    userspace_dc: dynamic.DynamicClient,
+    user_name: str,
+    expected_user_namespaces: Dict[str, str],
+    namespaces: List[str],
 ) -> None:
     for user_ns in namespaces:
         if user_ns not in expected_user_namespaces.values():
             delete_user_profile(user_profile=user_ns)
-
-            delete_user_efs_endpoint(user_name=user_name, user_namespace=user_ns, api=api)
-
             logger.info(f"User {user_name} is not expected to be part of the {user_ns} namespace. Removing...")
-
+            try:
+                userspace_dc.delete(name=user_ns, namespace=user_ns)
+                logger.info(f"Removed userspace custom resource {user_ns}")
+            except ApiException as ae:
+                logger.warning(f"Exception when trying to remove userspace custom resource {user_ns}")
+                logger.warning(ae.body)
             try:
                 api.delete_collection_namespaced_pod(namespace=user_ns, grace_period_seconds=0)
                 api.delete_namespace(name=user_ns)
                 logger.info(f"Removed namespace {user_ns}")
-            except ApiException:
-                logger.error(f"Exception when trying to remove user namespace {user_ns}")
+            except ApiException as ae:
+                logger.warning(f"Exception when trying to remove user namespace {user_ns}")
+                logger.warning(ae.body)
 
 
 def delete_user_profile(user_profile: str) -> None:
     logger.info(f"Removing profile {user_profile}")
     run_command(f"kubectl delete profile {user_profile} --kubeconfig {KUBECONFIG_PATH}")
-
     time.sleep(5)
 
 
-def manage_user_namespace(event: Dict[str, Any], api: client.CoreV1Api) -> None:
+def manage_user_namespace(event: Dict[str, Any], api: client.CoreV1Api, userspace_dc: dynamic.DynamicClient) -> None:
     user_name = cast(str, event.get("user_name"))
     user_email = cast(str, event.get("user_email"))
     expected_user_namespaces = cast(Dict[str, str], event.get("expected_user_namespaces"))
@@ -188,6 +217,7 @@ def manage_user_namespace(event: Dict[str, Any], api: client.CoreV1Api) -> None:
 
     create_user_namespace(
         api=api,
+        userspace_dc=userspace_dc,
         user_name=user_name,
         user_email=user_email,
         expected_user_namespaces=expected_user_namespaces,
@@ -196,6 +226,7 @@ def manage_user_namespace(event: Dict[str, Any], api: client.CoreV1Api) -> None:
 
     delete_user_namespace(
         api=api,
+        userspace_dc=userspace_dc,
         user_name=user_name,
         expected_user_namespaces=expected_user_namespaces,
         namespaces=all_ns,
