@@ -12,7 +12,7 @@ _logger: logging.Logger = logging.getLogger(__name__)
 
 
 def run_command(cmd: str) -> str:
-    """ Module to run shell commands. """
+    """Module to run shell commands."""
     try:
         output = subprocess.check_output(cmd, stderr=subprocess.STDOUT, shell=True, timeout=3, universal_newlines=True)
     except subprocess.CalledProcessError as exc:
@@ -21,26 +21,38 @@ def run_command(cmd: str) -> str:
     return output
 
 
+def check_cert(context: "FoundationContext") -> str:
+    ssl_cert_arn: str = cast(str, context.networking.frontend.ssl_cert_arn)
+    if ssl_cert_arn:
+        return ssl_cert_arn
+    else:
+        return deploy_selfsigned_cert(context)
+
+
 def deploy_selfsigned_cert(context: "FoundationContext") -> str:
-    """ Module to deploy self signed cert """
+    """Module to deploy self signed cert"""
 
     _logger.debug("Generating self-signed certificate...")
-    generate_cert: str = (
-        "openssl req -x509 -nodes -days 365 -newkey rsa:2048 "
-        "-keyout privateKey.key -out certificate.crt "
+
+    _logger.debug("Creating private key...")
+    convert_key: str = "openssl genrsa 2048 > private.pem"
+    run_command(cmd=convert_key)
+
+    _logger.debug("Creating Certificate signing request...")
+    generate_csr: str = (
+        "openssl req -new -key private.pem "
+        "-out csr.pem "
         '-subj "/C=US/ST=SEA/L=SEA/O=AWSOrbit Security/OU=AWSOrbit Department/CN=AWSOrbit"'
     )
-    run_command(cmd=generate_cert)
+    run_command(cmd=generate_csr)
+
+    _logger.debug("Creating Public certificate...")
+    generate_pub: str = "openssl x509 -req -days 365 -in csr.pem " "-signkey private.pem -out public.pem "
+    run_command(cmd=generate_pub)
 
-    _logger.debug("Converting the key into .pem file...")
-    convert_key: str = "openssl rsa -in privateKey.key -text > private.pem"
-    run_command(cmd=convert_key)
     with open("private.pem", "r") as fp:
         private_pem = fp.read()
 
-    _logger.debug("Converting the cert into .pem file...")
-    convert_pem: str = "openssl x509 -inform PEM -in certificate.crt > public.pem"
-    run_command(cmd=convert_pem)
     with open("public.pem", "r") as fp:
         public_pem = fp.read()
 
@@ -50,9 +62,9 @@ def deploy_selfsigned_cert(context: "FoundationContext") -> str:
 
 
 def upload_cert_iam(context: "FoundationContext", private_pem: str, public_pem: str) -> str:
-    """ Uploads the cert to AWS IAM """
+    """Uploads the cert to AWS IAM"""
     iam_client = boto3.client("iam")
-    ssl_cert_name = context.name
+    ssl_cert_name = f"{context.name}-{context.region}"
     try:
         response = iam_client.get_server_certificate(ServerCertificateName=ssl_cert_name)
         return cast(str, response["ServerCertificate"]["ServerCertificateMetadata"]["Arn"])
