@@ -13,8 +13,10 @@
 #    limitations under the License.
 
 import concurrent.futures
+import json
 import logging
 import os
+import subprocess
 from concurrent.futures import Future
 from typing import Any, List, Optional, Tuple, cast
 
@@ -23,7 +25,7 @@ from aws_orbit.models.changeset import Changeset, load_changeset_from_ssm
 from aws_orbit.models.context import Context, ContextSerDe, FoundationContext, TeamContext
 from aws_orbit.models.manifest import ImageManifest, ImagesManifest, Manifest, ManifestSerDe
 from aws_orbit.remote_files import cdk_toolkit, eksctl, env, foundation, helm, kubectl, teams, utils
-from aws_orbit.services import codebuild, ecr
+from aws_orbit.services import codebuild, ecr, kms, secretsmanager
 from aws_orbit.utils import boto3_client
 
 _logger: logging.Logger = logging.getLogger(__name__)
@@ -172,6 +174,35 @@ def deploy_images_remotely(manifest: Manifest, context: "Context", skip_images:
     _deploy_images_batch(manifest=manifest, context=context, images=images)
 
 
+def deploy_credentials(args: Tuple[str, ...]) -> None:
+    _logger.debug("args: %s", args)
+    if len(args) != 2:
+        raise ValueError("Unexpected number of values in args")
+    env_name: str = args[0]
+    ciphertext: str = args[1]
+    context: "Context" = ContextSerDe.load_context_from_ssm(env_name=env_name, type=Context)
+    _logger.debug("Context loaded.")
+
+    new_credentials = json.loads(kms.decrypt(context=context, ciphertext=ciphertext))
+    secret_id = f"orbit-{env_name}-docker-credentials"
+    existing_credentials = secretsmanager.get_secret_value(secret_id=secret_id)
+    for registry, creds in new_credentials.items():
+        username = creds.get("username", "")
+        password = creds.get("password", "")
+        try:
+            subprocess.check_call(
+                f"docker login --username '{username}' --password '{password}' {registry}", shell=True
+            )
+        except Exception as e:
+            _logger.error("Invalid Registry Credentials")
+            _logger.exception(e)
+            return
+        else:
+            existing_credentials = {**existing_credentials, **new_credentials}
+    secretsmanager.put_secret_value(secret_id=secret_id, secret=existing_credentials)
+    _logger.debug("Registry Credentials deployed")
+
+
 def deploy_foundation(args: Tuple[str, ...]) -> None:
     _logger.debug("args: %s", args)
     if len(args) != 1:
@@ -243,7 +274,10 @@ def _update_userpool(context: Context) -> None:
         f"arn:aws:lambda:{context.region}:{context.account_id}:function:orbit-{context.name}-post-authentication"
     )
 
-    cognito_client.update_user_pool(UserPoolId=context.user_pool_id, LambdaConfig={"PostAuthentication": function_arn})
+    cognito_client.update_user_pool(
+        UserPoolId=context.user_pool_id,
+        LambdaConfig={"PostAuthentication": function_arn, "PostConfirmation": function_arn},
+    )
 
 
 def _update_userpool_client(context: Context) -> None:
@@ -253,6 +287,8 @@ def _update_userpool_client(context: Context) -> None:
         ClientId=context.user_pool_client_id,
         CallbackURLs=[
             f"{context.landing_page_url}/oauth2/idpresponse",
+            f"{context.landing_page_url}/orbit/login",
+            f"{context.landing_page_url}/saml2/idpresponse",
         ],
         LogoutURLs=[
             f"{context.landing_page_url}/orbit/logout",
