@@ -24,15 +24,16 @@ from aws_orbit import sh
 from aws_orbit.models.changeset import Changeset, ListChangeset
 from aws_orbit.models.context import Context, ContextSerDe, TeamContext
 from aws_orbit.models.manifest import ManagedNodeGroupManifest
+from aws_orbit.remote_files.kubectl import deploy_eniconfig, set_secondary_vpc_cidr_env_vars
 from aws_orbit.services import autoscaling, cfn, ec2, eks, iam
-from aws_orbit.services.ec2 import IpPermission, UserIdGroupPair
+from aws_orbit.services.ec2 import IpPermission, UserIdGroupPair, get_az_from_subnet
 
 _logger: logging.Logger = logging.getLogger(__name__)
 
 MANIFEST: Dict[str, Any] = {
     "apiVersion": "eksctl.io/v1alpha5",
     "kind": "ClusterConfig",
-    "metadata": {"name": None, "region": None},
+    "metadata": {"name": None, "region": None, "version": "1.20"},
     "vpc": {"id": None, "cidr": None, "subnets": {"private": {}, "public": {}}},
     "iam": {"serviceRoleARN": None},
     "cloudWatch": {"clusterLogging": {"enableTypes": ["*"]}},
@@ -40,7 +41,14 @@ MANIFEST: Dict[str, Any] = {
 
 
 def create_nodegroup_structure(context: "Context", nodegroup: ManagedNodeGroupManifest) -> Dict[str, Any]:
-    labels = {"orbit/node-group": nodegroup.name, "orbit/usage": "teams", "orbit/node-type": "ec2"}
+    labels = {
+        "orbit/node-group": nodegroup.name,
+        "orbit/usage": "teams",
+        "orbit/node-type": "ec2",
+        "node-group": nodegroup.name,
+        "usage": "teams",
+        "node-type": "ec2",
+    }
     labels.update(nodegroup.labels)
 
     # Extra label for gpu instance types
@@ -53,7 +61,7 @@ def create_nodegroup_structure(context: "Context", nodegroup: ManagedNodeGroupMa
     tags = {f"k8s.io/cluster-autoscaler/node-template/label/{k}": v for k, v in labels.items()}
     tags["Env"] = f"orbit-{context.name}"
 
-    return {
+    config = {
         "name": nodegroup.name,
         "privateNetworking": True,
         "instanceType": nodegroup.instance_type,
@@ -67,6 +75,13 @@ def create_nodegroup_structure(context: "Context", nodegroup: ManagedNodeGroupMa
         "iam": {"instanceRoleARN": context.eks_env_nodegroup_role_arn},
     }
 
+    if nodegroup.availability_zones is not None:
+        config["availabilityZones"] = nodegroup.availability_zones
+    if nodegroup.efa_enabled is not None:
+        config["efaEnabled"] = nodegroup.efa_enabled
+
+    return config
+
 
 def generate_manifest(context: "Context", name: str, nodegroups: Optional[List[ManagedNodeGroupManifest]]) -> str:
     internet: bool = context.networking.data.internet_accessible
@@ -92,7 +107,16 @@ def generate_manifest(context: "Context", name: str, nodegroups: Optional[List[M
             "cidr": subnet.cidr_block,
         }
 
-    private_subnets = context.networking.private_subnets if internet else context.networking.isolated_subnets
+    private_subnets = [
+        s
+        for s in context.networking.private_subnets + context.networking.isolated_subnets
+        if s.subnet_id in context.networking.data.nodes_subnets
+    ]
+    if not private_subnets:
+        raise ValueError(
+            "No Non-public Subnets configured for the cluster, this may be a mismatch between "
+            "InternetAccessibility and Manifest Subnets"
+        )
     for subnet in private_subnets:
         if subnet.availability_zone is None:
             raise ValueError("subnet.availability_zone is None for %s!", subnet.subnet_id)
@@ -104,12 +128,26 @@ def generate_manifest(context: "Context", name: str, nodegroups: Optional[List[M
         }
 
     MANIFEST["iam"]["serviceRoleARN"] = context.eks_cluster_role_arn
+    MANIFEST["iam"]["withOIDC"] = True
     MANIFEST["managedNodeGroups"] = []
 
-    labels = {"orbit/node-group": "env", "orbit/usage": "reserved", "orbit/node-type": "ec2"}
+    labels = {
+        "orbit/node-group": "env",
+        "orbit/usage": "reserved",
+        "orbit/node-type": "ec2",
+        "node-group": "env",
+        "usage": "reserved",
+        "node-type": "ec2",
+    }
     tags = tags = {f"k8s.io/cluster-autoscaler/node-template/label/{k}": v for k, v in labels.items()}
     tags["Env"] = f"orbit-{context.name}"
 
+    MANIFEST["addons"] = [
+        {"name": "vpc-cni", "version": "v1.9.0", "attachPolicyARNs": ["arn:aws:iam::aws:policy/AmazonEKS_CNI_Policy"]},
+        {"name": "kube-proxy", "version": "v1.20.4-eksbuild.2"},
+        {"name": "coredns", "version": "v1.8.3-eksbuild.1"},
+    ]
+
     # Env
     MANIFEST["managedNodeGroups"].append(
         {
@@ -117,8 +155,8 @@ def generate_manifest(context: "Context", name: str, nodegroups: Optional[List[M
             "privateNetworking": True,
             "instanceType": "m5.large",
             "minSize": 2,
-            "desiredCapacity": 2,
-            "maxSize": 4,
+            "desiredCapacity": 3,
+            "maxSize": 6,
             "volumeSize": 64,
             "ssh": {"allow": False},
             "labels": labels,
@@ -311,7 +349,7 @@ def deploy_env(context: "Context", changeset: Optional[Changeset]) -> None:
     _logger.debug("Synthetizing the EKSCTL Environment manifest")
     cluster_name = f"orbit-{context.name}"
 
-    if cfn.does_stack_exist(stack_name=final_eks_stack_name) is False:
+    if not cfn.does_stack_exist(stack_name=final_eks_stack_name):
 
         requested_nodegroups = (
             changeset.managed_nodegroups_changeset.added_nodegroups
@@ -328,13 +366,21 @@ def deploy_env(context: "Context", changeset: Optional[Changeset]) -> None:
             "--write-kubeconfig --verbose 4"
         )
 
-        username = f"orbit-{context.name}-admin"
+        username = context.toolkit.admin_role
         arn = f"arn:aws:iam::{context.account_id}:role/{username}"
         _logger.debug(f"Adding IAM Identity Mapping - Role: {arn}, Username: {username}, Group: system:masters")
         sh.run(
             f"eksctl create iamidentitymapping --cluster {cluster_name} --arn {arn} "
             f"--username {username} --group system:masters"
         )
+
+        if context.networking.secondary_cidr:
+            set_secondary_vpc_cidr_env_vars()
+            subnet_ids = [subnet.subnet_id for subnet in context.networking.private_subnets]
+            _logger.debug(f"Getting AZ'z for the subnets: {subnet_ids}")
+            az_subnet_map = get_az_from_subnet(subnets=subnet_ids)
+            deploy_eniconfig(az_subnet_map=az_subnet_map, context=context)
+
         context.managed_nodegroups = requested_nodegroups
 
         for ng in requested_nodegroups:
@@ -410,7 +456,7 @@ def deploy_env(context: "Context", changeset: Optional[Changeset]) -> None:
     authorize_cluster_pod_security_group(context=context)
 
     iam.add_assume_role_statement(
-        role_name=f"orbit-{context.name}-cluster-autoscaler-role",
+        role_name=f"orbit-{context.name}-{context.region}-cluster-autoscaler-role",
         statement={
             "Effect": "Allow",
             "Principal": {"Federated": f"arn:aws:iam::{context.account_id}:oidc-provider/{context.eks_oidc_provider}"},
@@ -424,7 +470,7 @@ def deploy_env(context: "Context", changeset: Optional[Changeset]) -> None:
     )
 
     iam.add_assume_role_statement(
-        role_name=f"orbit-{context.name}-eks-cluster-role",
+        role_name=f"orbit-{context.name}-{context.region}-eks-cluster-role",
         statement={
             "Effect": "Allow",
             "Principal": {"Federated": f"arn:aws:iam::{context.account_id}:oidc-provider/{context.eks_oidc_provider}"},
@@ -438,7 +484,7 @@ def deploy_env(context: "Context", changeset: Optional[Changeset]) -> None:
     )
 
     iam.add_assume_role_statement(
-        role_name=f"orbit-{context.name}-admin",
+        role_name=cast(str, context.toolkit.admin_role),
         statement={
             "Effect": "Allow",
             "Principal": {"Federated": f"arn:aws:iam::{context.account_id}:oidc-provider/{context.eks_oidc_provider}"},
@@ -451,6 +497,16 @@ def deploy_env(context: "Context", changeset: Optional[Changeset]) -> None:
         },
     )
 
+    if not context.networking.data.internet_accessible:
+        eks.create_fargate_profile(
+            profile_name=f"orbit-{context.name}-system",
+            cluster_name=f"orbit-{context.name}",
+            role_arn=cast(str, context.eks_fargate_profile_role_arn),
+            subnets=[s.subnet_id for s in context.networking.private_subnets],
+            namespaces=["cert-manager", "istio-system", "kubeflow", "kube-system", "orbit-system"],
+            selector_labels={"orbit/node-type": "fargate"},
+        )
+
     _logger.debug("EKSCTL deployed")
 
 
@@ -462,12 +518,7 @@ def deploy_team(context: "Context", team_context: "TeamContext") -> None:
     cluster_name = f"orbit-{context.name}"
     if cfn.does_stack_exist(stack_name=final_eks_stack_name) and context.teams:
         if team_context.fargate:
-            subnets = (
-                context.networking.private_subnets
-                if context.networking.data.internet_accessible
-                else context.networking.isolated_subnets
-            )
-            subnets_ids = [s.subnet_id for s in subnets]
+            subnets_ids = context.networking.data.nodes_subnets
 
             sh.run(f"aws eks wait cluster-active --name orbit-{context.name} --debug")
 
@@ -476,7 +527,7 @@ def deploy_team(context: "Context", team_context: "TeamContext") -> None:
                 cluster_name=f"orbit-{context.name}",
                 role_arn=cast(str, context.eks_fargate_profile_role_arn),
                 subnets=subnets_ids,
-                namespace=team_context.name,
+                namespaces=[team_context.name],
                 selector_labels={"team": team_context.name, "orbit/node-type": "fargate"},
             )
 
@@ -484,16 +535,25 @@ def deploy_team(context: "Context", team_context: "TeamContext") -> None:
         arn = f"arn:aws:iam::{context.account_id}:role/{username}"
         for line in sh.run_iterating(f"eksctl get iamidentitymapping --cluster {cluster_name} --arn {arn}"):
             if line == f'Error: no iamidentitymapping with arn "{arn}" found':
-                _logger.debug(f"Adding IAM Identity Mapping - Role: {arn}, Username: {username}, Group: system:masters")
+                _logger.debug(f"Adding IAM Identity Mapping - Role: {arn}, Username: {username}")
                 sh.run(
-                    f"eksctl create iamidentitymapping --cluster {cluster_name} "
-                    f"--arn {arn} --username {username} --group system:masters"
+                    f"eksctl create iamidentitymapping --cluster {cluster_name} " f"--arn {arn} --username {username}"
                 )
                 break
         else:
-            _logger.debug(
-                f"Skipping existing IAM Identity Mapping - Role: {arn}, Username: {username}, Group: system:masters"
-            )
+            _logger.debug(f"Skipping existing IAM Identity Mapping - Role: {arn}, Username: {username}")
+
+        username = f"orbit-{context.name}-{team_context.name}"
+        arn = cast(str, team_context.eks_pod_role_arn)
+        for line in sh.run_iterating(f"eksctl get iamidentitymapping --cluster {cluster_name} --arn {arn}"):
+            if line == f'Error: no iamidentitymapping with arn "{arn}" found':
+                _logger.debug(f"Adding IAM Identity Mapping - Role: {arn}, Username: {username}")
+                sh.run(
+                    f"eksctl create iamidentitymapping --cluster {cluster_name} " f"--arn {arn} --username {username}"
+                )
+                break
+        else:
+            _logger.debug(f"Skipping existing IAM Identity Mapping - Role: {arn}, Username: {username}")
 
 
 def destroy_env(context: "Context") -> None:
@@ -531,6 +591,16 @@ def destroy_teams(context: "Context") -> None:
                 _logger.debug(f"Removing IAM Identity Mapping - Role: {arn}")
                 sh.run(f"eksctl delete iamidentitymapping --cluster {cluster_name} --arn {arn}")
 
+            username = f"orbit-{context.name}-{team.name}"
+            arn = cast(str, team.eks_pod_role_arn)
+            for line in sh.run_iterating(f"eksctl get iamidentitymapping --cluster {cluster_name} --arn {arn}"):
+                if line == f'Error: no iamidentitymapping with arn "{arn}" found':
+                    _logger.debug(f"Skipping non-existent IAM Identity Mapping - Role: {arn}")
+                    break
+            else:
+                _logger.debug(f"Removing IAM Identity Mapping - Role: {arn}")
+                sh.run(f"eksctl delete iamidentitymapping --cluster {cluster_name} --arn {arn}")
+
         _logger.debug("EKSCTL Teams destroyed")
 
 
