@@ -15,7 +15,10 @@
 import logging
 import os
 import shutil
-from typing import Any, Dict, List, Tuple
+import time
+from typing import Any, Dict, List, Optional, Tuple, cast
+
+import yaml
 
 import aws_orbit
 from aws_orbit import ORBIT_CLI_ROOT, exceptions, k8s, sh, utils
@@ -32,23 +35,55 @@ _logger: logging.Logger = logging.getLogger(__name__)
 MODELS_PATH = os.path.join(ORBIT_CLI_ROOT, "data", "kubectl")
 
 
-def _orbit_system_commons(context: "Context", output_path: str) -> None:
-    filename = "00-commons.yaml"
-    input = os.path.join(MODELS_PATH, "orbit-system", filename)
-    output = os.path.join(output_path, filename)
+def _generate_orbit_system_kustomizations(context: "Context", clean_up: bool = True) -> List[str]:
+    output_path = os.path.join(".orbit.out", context.name, "kubectl", "orbit-system")
+    os.makedirs(output_path, exist_ok=True)
+    if clean_up:
+        _cleanup_output(output_path=output_path)
 
-    with open(input, "r") as file:
-        content: str = file.read()
-    content = resolve_parameters(
-        content,
-        dict(
-            account_id=context.account_id,
-            region=context.region,
-            env_name=context.name,
-        ),
+    commons_output_path = _generate_orbit_system_commons_manifest(output_path=output_path, context=context)
+
+    return [commons_output_path]
+
+
+def _orbit_system_commons_base(output_path: str, context: Context) -> None:
+    os.makedirs(os.path.join(output_path, "base"), exist_ok=True)
+    filenames = ["kustomization.yaml", "00a-commons.yaml", "00b-cert-manager.yaml"]
+    for filename in filenames:
+        input = os.path.join(MODELS_PATH, "orbit-system", "commons", "base", filename)
+        output = os.path.join(output_path, "base", filename)
+        with open(input, "r") as file:
+            content: str = file.read()
+        content = resolve_parameters(
+            content,
+            dict(
+                account_id=context.account_id,
+                region=context.region,
+                env_name=context.name,
+                role_prefix=f"/{context.role_prefix}/" if context.role_prefix else "/",
+                secure_port="10260",
+            ),
+        )
+        with open(output, "w") as file:
+            file.write(content)
+
+
+def _generate_orbit_system_commons_manifest(output_path: str, context: "Context") -> str:
+    output_path = os.path.join(output_path, "commons")
+    os.makedirs(output_path, exist_ok=True)
+    _cleanup_output(output_path=output_path)
+    _orbit_system_commons_base(output_path=output_path, context=context)
+    overlays_path = os.path.join(output_path, "overlays")
+    src = (
+        os.path.join(MODELS_PATH, "orbit-system", "commons", "overlays", "private")
+        if context.networking.data.internet_accessible
+        else os.path.join(MODELS_PATH, "orbit-system", "commons", "overlays", "isolated")
     )
-    with open(output, "w") as file:
-        file.write(content)
+    shutil.copytree(
+        src=src,
+        dst=overlays_path,
+    )
+    return overlays_path
 
 
 def _kubeflow_namespaces(context: "Context", clean_up: bool = True) -> str:
@@ -71,6 +106,7 @@ def _kubeflow_namespaces(context: "Context", clean_up: bool = True) -> str:
                 env_name=context.name,
                 account_id=context.account_id,
                 region=context.region,
+                sts_ep="legacy" if context.networking.data.internet_accessible else "regional",
             ),
         )
         with open(output, "w") as file:
@@ -80,7 +116,7 @@ def _kubeflow_namespaces(context: "Context", clean_up: bool = True) -> str:
 
 
 def _orbit_controller(context: "Context", output_path: str) -> None:
-    filenames = ["01a-orbit-controller.yaml", "01b-cert-manager.yaml"]
+    filenames = ["01a-orbit-controller.yaml"]
 
     for filename in filenames:
         input = os.path.join(MODELS_PATH, "orbit-system", filename)
@@ -92,6 +128,7 @@ def _orbit_controller(context: "Context", output_path: str) -> None:
             content,
             dict(
                 env_name=context.name,
+                code_build_image=f"{context.images.code_build.repository}:" f"{context.images.code_build.version}",
                 orbit_controller_image=f"{context.images.orbit_controller.repository}:"
                 f"{context.images.orbit_controller.version}",
                 k8s_utilities_image=f"{context.images.k8s_utilities.repository}:"
@@ -107,7 +144,7 @@ def _orbit_controller(context: "Context", output_path: str) -> None:
 
 
 def _orbit_image_replicator(context: "Context", output_path: str) -> None:
-    filenames = ["01c-image-replicator.yaml"]
+    filenames = ["01b-image-replicator.yaml"]
 
     for filename in filenames:
         input = os.path.join(MODELS_PATH, "orbit-system", filename)
@@ -118,11 +155,11 @@ def _orbit_image_replicator(context: "Context", output_path: str) -> None:
         content = resolve_parameters(
             content,
             dict(
+                account_id=context.account_id,
+                region=context.region,
                 env_name=context.name,
                 orbit_controller_image=f"{context.images.orbit_controller.repository}:"
                 f"{context.images.orbit_controller.version}",
-                k8s_utilities_image=f"{context.images.k8s_utilities.repository}:"
-                f"{context.images.k8s_utilities.version}",
                 image_pull_policy="Always" if aws_orbit.__version__.endswith(".dev0") else "IfNotPresent",
             ),
         )
@@ -130,37 +167,15 @@ def _orbit_image_replicator(context: "Context", output_path: str) -> None:
             file.write(content)
 
 
-def _cluster_autoscaler(output_path: str, context: "Context") -> None:
-    filename = "02-cluster-autoscaler-autodiscover.yaml"
-    input = os.path.join(MODELS_PATH, "kube-system", filename)
-    output = os.path.join(output_path, filename)
-
-    with open(input, "r") as file:
-        content: str = file.read()
-    content = utils.resolve_parameters(
-        content,
-        dict(
-            account_id=context.account_id,
-            env_name=context.name,
-            cluster_name=f"orbit-{context.name}",
-            sts_ep="legacy" if context.networking.data.internet_accessible else "regional",
-            image_pull_policy="Always" if aws_orbit.__version__.endswith(".dev0") else "IfNotPresent",
-            use_static_instance_list=str(not context.networking.data.internet_accessible).lower(),
-        ),
-    )
-    with open(output, "w") as file:
-        file.write(content)
-
-
 def _ssm_agent_installer(output_path: str, context: "Context") -> None:
-    filename = "02-ssm-agent-daemonset-installer.yaml"
+    filename = "02a-ssm-agent-daemonset-installer.yaml"
     input = os.path.join(MODELS_PATH, "orbit-system", filename)
     output = os.path.join(output_path, filename)
     shutil.copyfile(src=input, dst=output)
 
 
 def _sm_operator_installer(output_path: str, context: "Context") -> None:
-    filename = "10-sm-operator.yaml"
+    filename = "10a-sm-operator.yaml"
     input = os.path.join(MODELS_PATH, "orbit-system", filename)
     output = os.path.join(output_path, filename)
     shutil.copyfile(src=input, dst=output)
@@ -182,11 +197,13 @@ def _team(context: "Context", team_context: "TeamContext", output_path: str) ->
             efsprivateapid=team_context.efs_private_ap_id if team_context.efs_private_ap_id else "",
             account_id=context.account_id,
             env_name=context.name,
+            role_prefix=f"/{context.role_prefix}/" if context.role_prefix else "/",
             team_kms_key_arn=team_context.team_kms_key_arn,
             team_security_group_id=team_context.team_security_group_id,
             cluster_pod_security_group_id=context.cluster_pod_sg_id,
             team_context=ContextSerDe.dump_context_to_str(team_context),
             env_context=ContextSerDe.dump_context_to_str(context),
+            region=context.region,
         ),
     )
     _logger.debug("Kubectl Team %s manifest:\n%s", team_context.name, content)
@@ -199,7 +216,7 @@ def _team(context: "Context", team_context: "TeamContext", output_path: str) ->
 
     with open(input, "r") as file:
         content = file.read()
-    content = utils.resolve_parameters(content, dict(team=team_context.name))
+    content = utils.resolve_parameters(content, dict(env_name=context.name, team=team_context.name))
     with open(output, "w") as file:
         file.write(content)
 
@@ -241,14 +258,13 @@ def _generate_kube_system_manifest(context: "Context", clean_up: bool = True) ->
     if clean_up:
         _cleanup_output(output_path=output_path)
 
-    _cluster_autoscaler(output_path=output_path, context=context)
-
     filenames = [
         "00-observability.yaml",
         "01-aws-vgpu-daemonset.yaml",
         "01-nvidia-daemonset.yaml",
         "02-cluster-autoscaler-autodiscover.yaml",
     ]
+
     for filename in filenames:
         input = os.path.join(MODELS_PATH, "kube-system", filename)
         output = os.path.join(output_path, filename)
@@ -259,6 +275,8 @@ def _generate_kube_system_manifest(context: "Context", clean_up: bool = True) ->
             content,
             dict(
                 account_id=context.account_id,
+                region=context.region,
+                role_prefix=f"/{context.role_prefix}/" if context.role_prefix else "/",
                 env_name=context.name,
                 cluster_name=f"orbit-{context.name}",
                 sts_ep="legacy" if context.networking.data.internet_accessible else "regional",
@@ -272,27 +290,47 @@ def _generate_kube_system_manifest(context: "Context", clean_up: bool = True) ->
     return output_path
 
 
+def set_secondary_vpc_cidr_env_vars() -> None:
+    sh.run("kubectl set env daemonset aws-node -n kube-system AWS_VPC_K8S_CNI_CUSTOM_NETWORK_CFG=true")
+    sh.run("kubectl set env daemonset aws-node -n kube-system ENI_CONFIG_LABEL_DEF=topology.kubernetes.io/zone")
+
+
+def deploy_eniconfig(az_subnet_map: Dict[str, str], context: "Context") -> None:
+    _logger.debug("Prepping eniconfig deployments...")
+    output_path = _generate_eni_configs(az_subnet_map, context, clean_up=True)
+    sh.run(f"kubectl apply -f {output_path}")
+    _logger.debug("Deployted eniconfig deployments...")
+
+
+def _generate_eni_configs(az_subnet_map: Dict[str, str], context: "Context", clean_up: bool) -> str:
+    output_path = os.path.join(".orbit.out", context.name, "kubectl", "networking")
+    os.makedirs(output_path, exist_ok=True)
+    if clean_up:
+        _cleanup_output(output_path=output_path)
+
+    output = os.path.join(output_path, "eniconfigs.yaml")
+    for subnet, az in az_subnet_map.items():
+        config = {
+            "apiVersion": "crd.k8s.amazonaws.com/v1alpha1",
+            "kind": "ENIConfig",
+            "metadata": {"name": az},
+            "spec": {"securityGroups": [context.cluster_pod_sg_id], "subnet": subnet},
+        }
+        _logger.debug(f"Eniconfig deployments adding...{config}")
+        with open(output, "a") as outfile:
+            yaml.dump(config, outfile, default_flow_style=False)
+            outfile.write("---")
+            outfile.write("\n")
+    return output
+
+
 def _generate_orbit_system_manifest(context: "Context", clean_up: bool = True) -> str:
     output_path = os.path.join(".orbit.out", context.name, "kubectl", "orbit-system")
     os.makedirs(output_path, exist_ok=True)
     if clean_up:
         _cleanup_output(output_path=output_path)
-    _orbit_system_commons(context=context, output_path=output_path)
-    _orbit_controller(context=context, output_path=output_path)
-    if context.account_id is None:
-        raise ValueError("context.account_id is None!")
-    if context.user_pool_id is None:
-        raise ValueError("context.user_pool_id is None!")
-    if context.user_pool_client_id is None:
-        raise ValueError("context.user_pool_client_id is None!")
-    if context.identity_pool_id is None:
-        raise ValueError("context.identity_pool_id is None!")
 
-    if context.install_image_replicator or not context.networking.data.internet_accessible:
-        _logger.debug("Deploying Pod Image Modifier and Image Replicator")
-        _orbit_image_replicator(output_path=output_path, context=context)
-    else:
-        _logger.debug("Skipping deployment of Pod Image Modifier and Image Replicator")
+    _orbit_controller(context=context, output_path=output_path)
 
     if context.install_ssm_agent:
         _logger.debug("Deploying SSM Agent Installer")
@@ -305,38 +343,82 @@ def _generate_orbit_system_manifest(context: "Context", clean_up: bool = True) -
     return output_path
 
 
-def _generate_env_manifest(context: "Context", clean_up: bool = True) -> Tuple[str, str]:
-    filename = "00-commons.yaml"
+def _generate_orbit_image_replicator_manifest(context: "Context", clean_up: bool = True) -> Optional[str]:
+    output_path = os.path.join(".orbit.out", context.name, "kubectl", "orbit-system")
+    os.makedirs(output_path, exist_ok=True)
+    if clean_up:
+        _cleanup_output(output_path=output_path)
+
+    if context.install_image_replicator or not context.networking.data.internet_accessible:
+        _logger.debug("Deploying Pod Image Modifier and Image Replicator")
+        _orbit_image_replicator(output_path=output_path, context=context)
+        return output_path
+    else:
+        _logger.debug("Skipping deployment of Pod Image Modifier and Image Replicator")
+        return None
+
+
+def _generate_orbit_system_env_kustomizations(context: "Context", clean_up: bool = True) -> List[str]:
     output_path = os.path.join(".orbit.out", context.name, "kubectl", "env")
     os.makedirs(output_path, exist_ok=True)
     if clean_up:
         _cleanup_output(output_path=output_path)
 
-    input = os.path.join(MODELS_PATH, "env", filename)
-    output = os.path.join(output_path, filename)
-    shutil.copyfile(src=input, dst=output)
+    env_output_path = _generate_orbit_system_env_manifest(output_path=output_path, context=context)
 
-    with open(input, "r") as file:
-        content = file.read()
+    return [env_output_path]
 
-    content = utils.resolve_parameters(
-        content,
-        dict(
-            env_name=context.name,
-            orbit_controller_image=f"{context.images.orbit_controller.repository}:"
-            f"{context.images.orbit_controller.version}",
-            k8s_utilities_image=f"{context.images.k8s_utilities.repository}:" f"{context.images.k8s_utilities.version}",
-            image_pull_policy="Always" if aws_orbit.__version__.endswith(".dev0") else "IfNotPresent",
-            certArn=context.networking.frontend.ssl_cert_arn,
-            cognitoAppClientId=context.user_pool_client_id,
-            cognitoUserPoolID=context.user_pool_id,
-            account_id=context.account_id,
-            region=context.region,
-            cognitoUserPoolDomain=context.cognito_external_provider_domain,
-        ),
+
+def _orbit_system_env_base(output_path: str, context: Context) -> None:
+    os.makedirs(os.path.join(output_path, "base"), exist_ok=True)
+    filenames = ["kustomization.yaml", "00-commons.yaml"]
+    for filename in filenames:
+        input = os.path.join(MODELS_PATH, "env", "base", filename)
+        output = os.path.join(output_path, "base", filename)
+        with open(input, "r") as file:
+            content: str = file.read()
+        content = utils.resolve_parameters(
+            content,
+            dict(
+                env_name=context.name,
+                orbit_controller_image=f"{context.images.orbit_controller.repository}:"
+                f"{context.images.orbit_controller.version}",
+                k8s_utilities_image=f"{context.images.k8s_utilities.repository}:"
+                f"{context.images.k8s_utilities.version}",
+                image_pull_policy="Always" if aws_orbit.__version__.endswith(".dev0") else "IfNotPresent",
+                certArn=context.networking.frontend.ssl_cert_arn,
+                cognitoAppClientId=context.user_pool_client_id,
+                cognitoUserPoolID=context.user_pool_id,
+                account_id=context.account_id,
+                region=context.region,
+                cognitoUserPoolDomain=context.cognito_external_provider_domain,
+            ),
+        )
+        with open(output, "w") as file:
+            file.write(content)
+
+
+def _generate_orbit_system_env_manifest(output_path: str, context: "Context") -> str:
+    _cleanup_output(output_path=output_path)
+    _orbit_system_env_base(output_path=output_path, context=context)
+    overlays_path = os.path.join(output_path, "overlays")
+    src = (
+        os.path.join(MODELS_PATH, "env", "overlays", "private")
+        if context.networking.data.internet_accessible
+        else os.path.join(MODELS_PATH, "env", "overlays", "isolated")
     )
-    with open(output, "w") as file:
-        file.write(content)
+    shutil.copytree(
+        src=src,
+        dst=overlays_path,
+    )
+    return overlays_path
+
+
+def _generate_kubeflow_patch(context: "Context", clean_up: bool = True) -> Tuple[str, str]:
+    output_path = os.path.join(".orbit.out", context.name, "kubectl", "env")
+    os.makedirs(output_path, exist_ok=True)
+    if clean_up:
+        _cleanup_output(output_path=output_path)
 
     # kubeflow jupyter launcher configmap
     input = os.path.join(MODELS_PATH, "kubeflow", "kf-jupyter-launcher.yaml")
@@ -354,12 +436,11 @@ def _generate_env_manifest(context: "Context", clean_up: bool = True) -> Tuple[s
         file.write(content)
 
     input = os.path.join(MODELS_PATH, "kubeflow", "kf-jupyter-patch.yaml")
-    output = os.path.join(output_path, "kf-jupyter-patch.yaml")
 
     with open(input, "r") as file:
         patch = file.read()
 
-    return (output_path, patch)
+    return output, patch
 
 
 def _prepare_team_context_path(context: "Context") -> str:
@@ -398,7 +479,11 @@ def fetch_kubectl_data(context: "Context", k8s_context: str) -> None:
 
     ingress_url: str = k8s.get_ingress_dns(name="istio-ingress", k8s_context=k8s_context, namespace="istio-system")
 
-    context.landing_page_url = f"https://{ingress_url}"
+    if context.networking.frontend.custom_domain_name:
+        context.landing_page_url = f"https://{context.networking.frontend.custom_domain_name}"
+    else:
+        context.landing_page_url = f"https://{ingress_url}"
+
     if context.cognito_external_provider:
         context.cognito_external_provider_redirect = context.landing_page_url
 
@@ -436,10 +521,16 @@ def _generate_efs_driver_manifest(output_path: str, context: "Context") -> str:
     return overlays_path
 
 
-#######
 def _fsx_driver_base(output_path: str, context: "Context") -> None:
     os.makedirs(os.path.join(output_path, "base"), exist_ok=True)
-    filenames = ["controller.yaml", "csidriver.yaml", "kustomization.yaml", "node.yaml", "rbac.yaml"]
+    filenames = [
+        "controller-deployment.yaml",
+        "controller-serviceaccount.yaml",
+        "csidriver.yaml",
+        "kustomization.yaml",
+        "node-daemonset.yaml",
+        "node-serviceaccount.yaml",
+    ]
     for filename in filenames:
         input = os.path.join(MODELS_PATH, "kube-system", "fsx_driver", "base", filename)
         output = os.path.join(output_path, "base", filename)
@@ -474,7 +565,36 @@ def _generate_fsx_driver_manifest(output_path: str, context: "Context") -> str:
     return overlays_path
 
 
-#######
+# Confirm orbit-system Service Endpoints
+def _confirm_endpoints(name: str, namespace: str, k8s_context: str) -> None:
+    addresses = k8s.get_service_addresses(name=name, namespace=namespace, k8s_context=k8s_context)
+    if addresses:
+        for address in addresses:
+            _logger.debug(
+                "Service: %s Namespace: %s Hostname: %s IP: %s",
+                name,
+                namespace,
+                address.get("hostname"),
+                address.get("ip"),
+            )
+    else:
+        raise Exception("No Endpoints found for Service: %s Namespace: %s", name, namespace)
+
+
+def _confirm_readiness(name: str, namespace: str, type: str, k8s_context: str) -> None:
+    for _ in range(20):
+        status = k8s.get_resource_status(name=name, namespace=namespace, type=type, k8s_context=k8s_context)
+        ready_replicas = status.get("ready_replicas")
+        if ready_replicas and int(ready_replicas) > 0:
+            _logger.debug("%s/%s ready", namespace, name)
+            break
+        else:
+            _logger.debug("%s/%s not yet ready, sleeping for 1 minute", namespace, name)
+            time.sleep(60)
+    else:
+        raise Exception("Timeout wating for Image Replicator to become ready")
+
+
 def write_kubeconfig(context: "Context") -> None:
     sh.run(f"eksctl utils write-kubeconfig --cluster orbit-{context.name} --set-kubeconfig-context")
 
@@ -486,6 +606,50 @@ def deploy_env(context: "Context") -> None:
         k8s_context = get_k8s_context(context=context)
         _logger.debug("k8s_context: %s", k8s_context)
 
+        # orbit-system kustomizations
+        output_paths = _generate_orbit_system_kustomizations(context=context)
+        for path in output_paths:
+            sh.run(f"kubectl apply -k {path} --context {k8s_context} --wait")
+
+        # Wait until cert-manager webhook is available
+        _confirm_endpoints(name="cert-manager-webhook", namespace="cert-manager", k8s_context=k8s_context)
+        _confirm_readiness(name="cert-manager", namespace="cert-manager", type="Deployment", k8s_context=k8s_context)
+        _confirm_readiness(
+            name="cert-manager-cainjector", namespace="cert-manager", type="Deployment", k8s_context=k8s_context
+        )
+
+        output_path: Optional[str] = _generate_orbit_system_manifest(context=context, clean_up=True)
+        sh.run(f"kubectl apply -f {output_path} --context {k8s_context} --wait")
+
+        output_path = _generate_orbit_image_replicator_manifest(context=context, clean_up=True)
+        if output_path is not None:
+            sh.run(f"kubectl apply -f {output_path} --context {k8s_context} --wait")
+
+        # Commented until we confirm this isn't needed
+        # Restart orbit-system deployments and statefulsets to force reload of caches etc
+        # sh.run(f"kubectl rollout restart deployments -n orbit-system --context {k8s_context}")
+
+        _confirm_readiness(
+            name="podsetting-operator", namespace="orbit-system", type="deployment", k8s_context=k8s_context
+        )
+        _confirm_readiness(
+            name="teamspace-operator", namespace="orbit-system", type="deployment", k8s_context=k8s_context
+        )
+        _confirm_readiness(
+            name="userspace-operator", namespace="orbit-system", type="deployment", k8s_context=k8s_context
+        )
+        _confirm_endpoints(name="podsetting-pod-webhook", namespace="orbit-system", k8s_context=k8s_context)
+
+        if context.install_image_replicator or not context.networking.data.internet_accessible:
+            _confirm_readiness(
+                name="imagereplication-operator", namespace="orbit-system", type="deployment", k8s_context=k8s_context
+            )
+            _confirm_endpoints(name="imagereplication-pod-webhook", namespace="orbit-system", k8s_context=k8s_context)
+            sh.run(
+                "kubectl rollout restart daemonsets -n orbit-system-ssm-daemons "
+                f"ssm-agent-installer --context {k8s_context}"
+            )
+
         # kube-system kustomizations
         output_paths = _generate_kube_system_kustomizations(context=context)
         for output_path in output_paths:
@@ -493,12 +657,10 @@ def deploy_env(context: "Context") -> None:
 
         # kube-system manifests
         output_path = _generate_kube_system_manifest(context=context)
-        sh.run(f"kubectl delete jobs -l app=cert-manager -n orbit-system --context {k8s_context} --wait")
         sh.run(f"kubectl apply -f {output_path} --context {k8s_context} --wait")
 
-        # orbit-system
-        output_path = _generate_orbit_system_manifest(context=context)
-        sh.run(f"kubectl apply -f {output_path} --context {k8s_context} --wait")
+        # Enable ENIs
+        _enable_eni(k8s_context=k8s_context)
 
         # kubeflow-namespaces
         output_path = _kubeflow_namespaces(context=context)
@@ -507,42 +669,78 @@ def deploy_env(context: "Context") -> None:
         kubeflow.deploy_kubeflow(context=context)
 
         # env
-        (output_path, patch) = _generate_env_manifest(context=context)
-        sh.run(f"kubectl apply -f {output_path} --context {k8s_context} --wait")
+        output_paths = _generate_orbit_system_env_kustomizations(context=context)
+        for output_path in output_paths:
+            sh.run(f"kubectl apply -k {output_path} --context {k8s_context} --wait")
+
         # Patch Kubeflow
         _logger.debug("Orbit applying KubeFlow patch")
-        sh.run(f'kubectl patch deployment jupyter-web-app-deployment --patch "{patch}" -n kubeflow')
+        jupyter_launcher_config_map, patch = _generate_kubeflow_patch(context=context)
+        sh.run(f"kubectl apply -f {jupyter_launcher_config_map} --context {k8s_context} --wait")
+        sh.run(f'kubectl patch deployment -n kubeflow jupyter-web-app-deployment --patch "{patch}"')
         sh.run("kubectl rollout restart deployment jupyter-web-app-deployment -n kubeflow")
-        # Enable ENIs
-        sh.run(f"kubectl set env daemonset aws-node -n kube-system --context {k8s_context} ENABLE_POD_ENI=true")
+
+        _apply_deployment_patch_force_env_nodes("istio-system")
+        _apply_deployment_patch_force_env_nodes("knative-serving")
+        _apply_deployment_patch_force_env_nodes("kube-system")
+        _apply_deployment_patch_force_env_nodes("kubeflow")
+
+        # Patch Pods to push into Fargate when deploying in an isolated subnet
+        if not context.networking.data.internet_accessible:
+            patch = (
+                '{"spec":{"template":{"metadata":{"labels":{"orbit/node-type":"fargate"}},'
+                '"spec":{"nodeSelector": null}}}}'
+            )
+            sh.run(f"kubectl patch deployment -n istio-system authzadaptor --patch '{patch}'")
+
+            patch = (
+                '{"spec":{"template":{"metadata":{"labels":{"orbit/node-type":"fargate"}},'
+                '"spec":{"nodeSelector": null, "containers":[{"name":"alb-ingress-controller","args":'
+                '["--ingress-class=alb","--cluster-name=$(CLUSTER_NAME)","--aws-vpc-id=VPC_ID"]}]}}}}'
+            )
+            patch = patch.replace("VPC_ID", cast(str, context.networking.vpc_id))
+            sh.run(f"kubectl patch deployment -n kubeflow alb-ingress-controller --patch '{patch}'")
+
+        # Patch the kubeflow mpi-operator deployment to version lock the images to v0.2.3
+        patch = (
+            '{"spec":{"template":{"spec":{"containers":[{"name":"mpi-operator","args":["-alsologtostderr",'
+            '"--lock-namespace","kubeflow","--kubectl-delivery-image","mpioperator/kubectl-delivery:v0.2.3"],'
+            '"image":"mpioperator/mpi-operator:v0.2.3"}]}}}}'
+        )
+        sh.run(f"kubectl patch deployment -n kubeflow mpi-operator --patch '{patch}'")
+
+        # Confirm env Service Endpoints
+        _confirm_endpoints(name="landing-page-service", namespace="orbit-system", k8s_context=k8s_context)
+
+
+def _enable_eni(k8s_context: str) -> None:
+    _logger.debug("Setting aws-node daemonset in kube-system -- ENABLE_POD_ENI=true")
+    sh.run(f"kubectl set env daemonset aws-node -n kube-system --context {k8s_context} ENABLE_POD_ENI=true")
+
+    _logger.debug("Patch aws-node daemonset, container aws-vpc-cni-init -- DISABLE_TCP_EARLY_DEMUX=true")
+    patch = (
+        '{"spec": {"template": {"spec": {"initContainers": '
+        '[{"env":[{"name":"DISABLE_TCP_EARLY_DEMUX","value":"true"}],"name":"aws-vpc-cni-init"}]}}}}'
+    )
+    sh.run(f"kubectl patch daemonset aws-node -n kube-system --context {k8s_context} --patch '{patch}'")
+
+
+def _apply_deployment_patch_force_env_nodes(namespace: str) -> None:
+    _logger.debug(f"Force {namespace} deployments to env nodes")
+    patch = (
+        '{"spec":{"template":{"metadata":{"labels":{"orbit/node-type":"ec2"}},'
+        '"spec":{"nodeSelector":{"orbit/usage":"reserved","orbit/node-group":"env"}}}}}'
+    )
+    try:
         sh.run(
-            f"kubectl set env daemonset aws-node -n kube-system --context {k8s_context} DISABLE_TCP_EARLY_DEMUX=true"
+            f"bash -c 'for dep in $(kubectl get deployments -n {namespace} "
+            f"--output=jsonpath={{.items..metadata.name}}); "
+            f"do kubectl patch deployment $dep -n {namespace} --patch '\"'\"'{patch}'\"'\"'; "
+            f"done'"
         )
 
-        # Restart orbit-system deployments and statefulsets to force reload of caches etc
-        sh.run(f"kubectl rollout restart deployments -n orbit-system --context {k8s_context}")
-        sh.run(f"kubectl rollout restart statefulsets -n orbit-system --context {k8s_context}")
-
-        # Confirm orbit-system Service Endpoints
-        def confirm_endpoints(name: str, namespace: str) -> None:
-            subsets = k8s.get_service_endpoints(name=name, namespace=namespace, k8s_context=k8s_context)
-            if subsets:
-                for subset in subsets:
-                    for address in subset.get("addresses", []):
-                        _logger.debug(
-                            "Service: %s Namespace: %s Hostname: %s IP: %s",
-                            name,
-                            namespace,
-                            address.get("hostname"),
-                            address.get("ip"),
-                        )
-            else:
-                raise Exception("No Endpoints found for Service: %s Namespace: %s", name, namespace)
-
-        confirm_endpoints(name="podsettings-pod-modifier", namespace="orbit-system")
-        confirm_endpoints(name="landing-page-service", namespace="orbit-system")
-        if context.install_image_replicator or not context.networking.data.internet_accessible:
-            confirm_endpoints(name="pod-image-updater", namespace="orbit-system")
+    except FailedShellCommand:
+        _logger.debug(f"Ignoring failed moving of {namespace} pods to env nodes")
 
 
 def deploy_team(context: "Context", team_context: "TeamContext") -> None:
@@ -552,17 +750,8 @@ def deploy_team(context: "Context", team_context: "TeamContext") -> None:
         k8s_context = get_k8s_context(context=context)
         _logger.debug("kubectl context: %s", k8s_context)
         output_path = _generate_team_context(context=context, team_context=team_context)
-
         sh.run(f"kubectl apply -f {output_path} --context {k8s_context} --wait")
 
-        (output_path, patch) = _generate_env_manifest(context=context, clean_up=False)
-        sh.run(f"kubectl apply -f {output_path} --context {k8s_context} --wait")
-
-        # Patch Kubeflow
-        _logger.debug("Orbit applying KubeFlow patch")
-        sh.run(f'kubectl patch deployment jupyter-web-app-deployment --patch "{patch}" -n kubeflow')
-        sh.run("kubectl rollout restart deployment jupyter-web-app-deployment -n kubeflow")
-
 
 def destroy_env(context: "Context") -> None:
     eks_stack_name: str = f"eksctl-orbit-{context.name}-cluster"
@@ -571,7 +760,6 @@ def destroy_env(context: "Context") -> None:
         sh.run(f"eksctl utils write-kubeconfig --cluster orbit-{context.name} --set-kubeconfig-context")
         k8s_context = get_k8s_context(context=context)
         _logger.debug("kubectl k8s_context: %s", k8s_context)
-        output_path = _generate_orbit_system_manifest(context=context)
         try:
             # Here we remove some finalizers that can cause our delete to hang indefinitely
             try:
@@ -583,10 +771,18 @@ def destroy_env(context: "Context") -> None:
             except FailedShellCommand:
                 _logger.debug("Ignoring patch failure")
 
+            output_path = _generate_orbit_system_manifest(context=context)
             sh.run(
                 f"kubectl delete -f {output_path} --grace-period=0 --force "
                 f"--ignore-not-found --wait --context {k8s_context}"
             )
+            output_paths = _generate_orbit_system_kustomizations(context=context, clean_up=True)
+            for output_path in output_paths:
+                sh.run(
+                    f"kubectl delete -k {output_path} --grace-period=0 --force "
+                    f"--ignore-not-found --wait --context {k8s_context}"
+                )
+
         except exceptions.FailedShellCommand as ex:
             _logger.debug("Skipping: %s", ex)
             pass  # Let's leave for eksctl, it will destroy everything anyway...
