@@ -123,6 +123,7 @@ def start(
     bundle_location: str,
     buildspec: Dict[str, Any],
     timeout: int,
+    overrides: Optional[Dict[str, Any]] = None,
 ) -> str:
     client = boto3_client("codebuild")
     repo: Optional[str] = None
@@ -155,6 +156,10 @@ def start(
         build_params["imageOverride"] = repo
     if credentials:
         build_params["imagePullCredentialsTypeOverride"] = credentials
+
+    if overrides:
+        build_params = {**build_params, **overrides}
+
     response: Dict[str, Any] = client.start_build(**build_params)
     return str(response["build"]["id"])
 
@@ -239,8 +244,8 @@ def generate_spec(
     post: List[str] = [] if cmds_post is None else cmds_post
     install = [
         (
-            "nohup /usr/sbin/dockerd --host=unix:///var/run/docker.sock"
-            " --host=tcp://0.0.0.0:2375 --storage-driver=overlay&"
+            "nohup /usr/local/bin/dockerd --host=unix:///var/run/docker.sock"
+            " --host=tcp://127.0.0.1:2375 --storage-driver=overlay2&"
         ),
         'timeout 15 sh -c "until docker info; do echo .; sleep 1; done"',
     ]
@@ -261,6 +266,11 @@ def generate_spec(
     else:
         install.append(f"pip install aws-orbit~={__version__}")
 
+    # Login with any store Docker Registry credentials
+    install.append(
+        "/var/scripts/retrieve_docker_creds.py && echo 'Docker logins successful' || echo 'Docker logins failed'"
+    )
+
     # Plugins
     if plugins and isinstance(context, Context):
         for team_context in context.teams:
